@@ -18,7 +18,7 @@
    
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: laguerre.c,v 1.5 2001/06/02 21:40:21 beerli Exp $
+$Id: laguerre.c,v 1.6 2001/07/25 19:27:24 beerli Exp $
 */
 #include "migration.h"
 #include "laguerre.h"
@@ -32,14 +32,14 @@ $Id: laguerre.c,v 1.5 2001/06/02 21:40:21 beerli Exp $
 and is called with
 gcc -DLAGUERRE_TEST -g laguerre.c -o laguerre -lm*/
 
-#ifdef LAGUERRE_TEST 
+#ifdef LAGUERRE_TEST
 /* at the end is a test main to help test if the root/weights finding
    is OK*/
 
 /* if machine has lgamma() use it otherwise use lgamma from
    tools.h*/
 #undef LGAMMA
-#define LGAMMA lgamma 
+#define LGAMMA lgamma
 
 
 /* for migrate this is defined in tools.h */
@@ -77,32 +77,32 @@ logfac (long n)
     case 12:
       return 19.98721449566188614951736238706;
     default:
-      return LGAMMA(n + 1.);
+      return LGAMMA (n + 1.);
     }
 }
 #endif
 
 /* prototypes */
-double hermite(long n, double x);
-void root_hermite(long n, double *hroot);
-double  halfroot(double (*func)(long m, double x), 
+double hermite (long n, double x);
+void root_hermite (long n, double *hroot);
+double halfroot (double (*func) (long m, double x),
 		 long n, double startx, double delta);
-void hermite_weight(long n, double * hroot, double * weights);
-void inithermitcat(long categs, double alpha, double theta1, 
-		   double *rate, double *probcat);
+void hermite_weight (long n, double *hroot, double *weights);
+void inithermitcat (long categs, double alpha, double theta1,
+		    double *rate, double *probcat);
 
 double glaguerre (long m, double b, double x);
-void initlaguerrecat(long categs, double alpha, double theta1, 
-		   double *rate, double *probcat);
-void roots_laguerre(long m, double b, double **lgroot);
+void initlaguerrecat (long categs, double alpha, double theta1,
+		      double *rate, double *probcat);
+void roots_laguerre (long m, double b, double **lgroot);
 
-void initgammacat (long categs, double alpha, double theta1, 
+void initgammacat (long categs, double alpha, double theta1,
 		   double *rate, double *probcat);
 
-void integrate_laguerre(long categs, double *rate, 
-			double *probcat, 
-			double (*func)(double theta, helper_fmt * b), 
-			helper_fmt *helper, double *result, double *rmax);
+void integrate_laguerre (long categs, double *rate,
+			 double *probcat,
+			 double (*func) (double theta, helper_fmt * b),
+			 helper_fmt * helper, double *result, double *rmax);
 
 
 /*------------------------------------------------------
@@ -111,7 +111,7 @@ void integrate_laguerre(long categs, double *rate,
 */
 double
 glaguerre (long m, double b, double x)
-{				
+{
   long i;
   double gln, glnm1, glnp1;	/* L_n, L_(n-1), L_(n+1) */
 
@@ -140,41 +140,43 @@ glaguerre (long m, double b, double x)
 
 /* calculates hermite polynomial with degree n and parameter x */
 /* seems to be unprecise for n>13 -> root finder does not converge*/
-double hermite(long n, double x)
+double
+hermite (long n, double x)
 {
- double   h1 = 1.;
- double   h2 =  2. * x;
- double   xx =  2. * x;
- long i;
- for(i = 1; i < n; i++)
-   {
-     xx = 2. * x * h2 - 2. * (i) * h1;
-     h1 = h2;
-     h2 = xx;
-   }
- return xx;
+  double h1 = 1.;
+  double h2 = 2. * x;
+  double xx = 2. * x;
+  long i;
+  for (i = 1; i < n; i++)
+    {
+      xx = 2. * x * h2 - 2. * (i) * h1;
+      h1 = h2;
+      h2 = xx;
+    }
+  return xx;
 }
 
-void root_hermite(long n, double *hroot)
+void
+root_hermite (long n, double *hroot)
 {
-  long z=0;
+  long z = 0;
   long ii;
   long start;
-  if(n % 2 == 0)
+  if (n % 2 == 0)
     {
-      start = n/2;
+      start = n / 2;
       z = 1;
     }
   else
     {
-      start = n/2 + 1;
-      z=2;
-      hroot[start-1] = 0.0;
+      start = n / 2 + 1;
+      z = 2;
+      hroot[start - 1] = 0.0;
     }
-  for(ii=start; ii<n; ii++)
+  for (ii = start; ii < n; ii++)
     {
-      /* search only upwards*/
-      hroot[ii] = halfroot(hermite,n,hroot[ii-1]+EPSILON, 1./n);
+      /* search only upwards */
+      hroot[ii] = halfroot (hermite, n, hroot[ii - 1] + EPSILON, 1. / n);
       hroot[start - z] = -hroot[ii];
       z++;
     }
@@ -186,23 +188,22 @@ void root_hermite(long n, double *hroot)
   delta should be small.
   (*func) is a function with two arguments
 */
-double 
-halfroot(double (*func)(long m, double x), 
-	 long n, double startx, 
-	 double delta)
-{				
+double
+halfroot (double (*func) (long m, double x),
+	  long n, double startx, double delta)
+{
   double xl;
   double xu;
-  double xm=0.;
+  double xm = 0.;
   double fu;
-  double fl; 
+  double fl;
   double fm = 100000.;
   double gradient;
-  boolean down=FALSE;
+  boolean down = FALSE;
   /* decide if we search above or below startx and escapes to trace back 
      to the starting point that most often will be 
-     the root from the previous calculation*/
-  if(delta < 0)
+     the root from the previous calculation */
+  if (delta < 0)
     {
       xu = startx;
       xl = xu + delta;
@@ -212,29 +213,29 @@ halfroot(double (*func)(long m, double x),
       xl = startx;
       xu = xl + delta;
     }
-  delta = fabs(delta);
-  fu = (*func)(n, xu);
-  fl = (*func)(n, xl);
-  gradient = (fl-fu)/(xl-xu);      
+  delta = fabs (delta);
+  fu = (*func) (n, xu);
+  fl = (*func) (n, xl);
+  gradient = (fl - fu) / (xl - xu);
 
-  while(fabs(fm) > EPSILON)
+  while (fabs (fm) > EPSILON)
     {
-      /* is root outside of our bracket?*/
-      if((fu<0.0 && fl<0.0) || (fu>0.0 && fl > 0.0))
+      /* is root outside of our bracket? */
+      if ((fu < 0.0 && fl < 0.0) || (fu > 0.0 && fl > 0.0))
 	{
 	  xu += delta;
-	  fu = (*func)(n, xu);
-	  fl = (*func)(n, xl);
-	  gradient = (fl-fu)/(xl-xu);
+	  fu = (*func) (n, xu);
+	  fl = (*func) (n, xl);
+	  gradient = (fl - fu) / (xl - xu);
 	  down = gradient < 0 ? TRUE : FALSE;
 	}
       else
 	{
 	  xm = xl - fl / gradient;
-	  fm = (*func)(n, xm);
-	  if(down)
+	  fm = (*func) (n, xm);
+	  if (down)
 	    {
-	      if(fm > 0.)
+	      if (fm > 0.)
 		{
 		  xl = xm;
 		  fl = fm;
@@ -247,7 +248,7 @@ halfroot(double (*func)(long m, double x),
 	    }
 	  else
 	    {
-	      if(fm > 0.)
+	      if (fm > 0.)
 		{
 		  xu = xm;
 		  fu = fm;
@@ -258,7 +259,7 @@ halfroot(double (*func)(long m, double x),
 		  fl = fm;
 		}
 	    }
-	  gradient = (fl-fu)/(xl-xu); 
+	  gradient = (fl - fu) / (xl - xu);
 	}
     }
   return xm;
@@ -268,46 +269,47 @@ halfroot(double (*func)(long m, double x),
 // calculate the weights for the hermite polynomial
 // at the roots 
 // using formula Abramowitz and Stegun chapter 25.4.46 p.890
-void hermite_weight(long n, double * hroot, double * weights)
+void
+hermite_weight (long n, double *hroot, double *weights)
 {
   long i;
   double hr2;
-  double nominator = exp(LOG2 * ( n-1.) + logfac(n)) * SQRTPI / (n*n);
-  for(i=0;i<n; i++)
+  double nominator = EXP (LOG2 * (n - 1.) + logfac (n)) * SQRTPI / (n * n);
+  for (i = 0; i < n; i++)
     {
-      hr2 = hermite(n-1, hroot[i]);
-      weights[i] = nominator / (hr2*hr2);
+      hr2 = hermite (n - 1, hroot[i]);
+      weights[i] = nominator / (hr2 * hr2);
     }
 }
 
 /* calculates rates and LOG(probabilities) */
-void 
-inithermitcat(long categs, double alpha, double theta1, 
-	      double *rate, double *probcat)
+void
+inithermitcat (long categs, double alpha, double theta1,
+	       double *rate, double *probcat)
 {
   long i;
   double *hroot;
-  double std = SQRT2 * theta1/sqrt(alpha);
-  hroot = (double *) calloc(categs+1,sizeof(double));
-  root_hermite(categs, hroot);  // calculate roots
-  hermite_weight(categs, hroot, probcat);  // set weights
-  for(i=0;i<categs;i++)  // set rates
+  double std = SQRT2 * theta1 / sqrt (alpha);
+  hroot = (double *) calloc (categs + 1, sizeof (double));
+  root_hermite (categs, hroot);	// calculate roots
+  hermite_weight (categs, hroot, probcat);	// set weights
+  for (i = 0; i < categs; i++)	// set rates
     {
       rate[i] = theta1 + std * hroot[i];
-      probcat[i] = log(probcat[i]);
+      probcat[i] = log (probcat[i]);
     }
-  free(hroot);
+  free (hroot);
 }
 
 void
-roots_laguerre(long m, double b, double **lgroot)
-{				
+roots_laguerre (long m, double b, double **lgroot)
+{
   /* For use by initgammacat.  
      Get roots of m-th Generalized Laguerre polynomial, given roots 
      of (m-1)-th, these are to be stored in lgroot[m][] */
   long i;
   double upper, lower, x, y;
-  boolean dwn=FALSE;	   
+  boolean dwn = FALSE;
   double tmp;
   /* is function declining in this interval? */
   if (m == 1)
@@ -342,7 +344,7 @@ roots_laguerre(long m, double b, double **lgroot)
 	  while (upper - lower > 0.000000001)
 	    {
 	      x = (upper + lower) / 2.0;
-	      if ((tmp=glaguerre (m, b, x)) > 0.0)
+	      if ((tmp = glaguerre (m, b, x)) > 0.0)
 		{
 		  if (dwn)
 		    lower = x;
@@ -365,36 +367,37 @@ roots_laguerre(long m, double b, double **lgroot)
 
 
 void
-initgammacat (long categs, double alpha, double theta1, 
+initgammacat (long categs, double alpha, double theta1,
 	      double *rate, double *probcat)
-{				
+{
 /* calculate rates and probabilities to approximate Gamma distribution
    of rates with "categs" categories and shape parameter "alpha" using
    rates and weights from Generalized Laguerre quadrature */
 
-  if(alpha>=100.)
+  if (alpha >= 100.)
     {
-      inithermitcat(categs, alpha, theta1, rate, probcat);
+      inithermitcat (categs, alpha, theta1, rate, probcat);
     }
   else
     {
-      initlaguerrecat(categs, alpha, theta1, rate, probcat);
+      initlaguerrecat (categs, alpha, theta1, rate, probcat);
     }
 }
 
-void      
-initlaguerrecat(long categs, double alpha, double theta1, double *rate, 
-		double *probcat)
+void
+initlaguerrecat (long categs, double alpha, double theta1, double *rate,
+		 double *probcat)
 {
   long i;
-  double  **lgroot;		/* roots of GLaguerre polynomials */
+  double **lgroot;		/* roots of GLaguerre polynomials */
   double f, x, xi, y;
-  
-  lgroot = (double **) calloc(categs+1,sizeof(double*));
-  lgroot[0] = (double *) calloc((categs+1)*(categs+1),sizeof(double));
-  for(i=1;i<categs+1;i++)
+
+  lgroot = (double **) calloc (categs + 1, sizeof (double *));
+  lgroot[0] =
+    (double *) calloc ((categs + 1) * (categs + 1), sizeof (double));
+  for (i = 1; i < categs + 1; i++)
     {
-      lgroot[i] = lgroot[0] + i * (categs+1);
+      lgroot[i] = lgroot[0] + i * (categs + 1);
     }
   lgroot[1][1] = 1.0 + alpha;
   for (i = 2; i <= categs; i++)
@@ -413,75 +416,67 @@ initlaguerrecat(long categs, double alpha, double theta1, double *rate,
       rate[i - 1] = xi / (1.0 + alpha);
       probcat[i - 1] = x;
     }
-  for(i=0;i<categs;i++)
+  for (i = 0; i < categs; i++)
     {
-      probcat[i] = log(probcat[i]);
+      probcat[i] = log (probcat[i]);
       rate[i] *= theta1;
     }
-  free(lgroot[0]);
-  free(lgroot);
+  free (lgroot[0]);
+  free (lgroot);
 }				/* initgammacat */
 
 
-void integrate_laguerre(long categs, double *rate, 
-			double *probcat, 
-			double (*func)(double theta, helper_fmt * b), 
-			helper_fmt *helper, double *result, double *rmax)
+void
+integrate_laguerre (long categs, double *rate,
+		    double *probcat,
+		    double (*func) (double theta, helper_fmt * b),
+		    helper_fmt * helper, double *result, double *rmax)
 {
-  double summ=0.;
+  double summ = 0.;
   long i;
   double *temp;
   int *stemp;
   *rmax = -DBL_MAX;
 
-  temp = (double *) calloc(categs, sizeof(double));
-  stemp = (int *) calloc(categs, sizeof(int));
-  for(i=0;i<categs;i++)
-    { 
-      temp[i] = (*func)(rate[i], (void *)helper);
+  temp = (double *) calloc (categs, sizeof (double));
+  stemp = (int *) calloc (categs, sizeof (int));
+  for (i = 0; i < categs; i++)
+    {
+      temp[i] = (*func) (rate[i], (void *) helper);
       stemp[i] = helper->sign;
-      if(temp[i] > *rmax)
+      if (temp[i] > *rmax)
 	*rmax = temp[i];
     }
-  for(i=0;i<categs;i++)
+  for (i = 0; i < categs; i++)
     {
-      summ += ((double) stemp[i]) * probcat[i] * exp(temp[i] - *rmax);
+      summ += ((double) stemp[i]) * probcat[i] * EXP (temp[i] - *rmax);
     }
-  free(temp);
-  free(stemp);
-  *result =  summ;
+  free (temp);
+  free (stemp);
+  *result = summ;
 }
 
 
 /* initgammacat test function*/
 #ifdef LAGUERRE_TEST
-int main()
+int
+main ()
 {
-  long categs=10;
+  long categs = 10;
   double alpha;
   double theta1;
   double *rate;
   double *probcat;
   long i;
-  printf("Enter alpha, theta1,  and categs\n");
-  fscanf(stdin,"%lf%lf%li",&alpha,&theta1,&categs);
-  rate = (double *) calloc(categs+1,sizeof(double));
-  probcat = (double *) calloc(categs+1,sizeof(double));
-  initgammacat(categs, alpha, theta1, rate,probcat);
-  for(i=0;i<categs;i++)
+  printf ("Enter alpha, theta1,  and categs\n");
+  fscanf (stdin, "%lf%lf%li", &alpha, &theta1, &categs);
+  rate = (double *) calloc (categs + 1, sizeof (double));
+  probcat = (double *) calloc (categs + 1, sizeof (double));
+  initgammacat (categs, alpha, theta1, rate, probcat);
+  for (i = 0; i < categs; i++)
     {
-      printf("%20.20f %20.20f\n",rate[i],probcat[i]);
+      printf ("%20.20f %20.20f\n", rate[i], probcat[i]);
     }
   return 0;
 }
 #endif
-
-
-
-
-
-
-
-
-
-
