@@ -13,7 +13,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: mcmc1.c,v 1.54 2001/06/02 21:40:21 beerli Exp $
+$Id: mcmc1.c,v 1.55 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "random.h"
@@ -36,27 +36,37 @@ $Id: mcmc1.c,v 1.54 2001/06/02 21:40:21 beerli Exp $
 long metropolize (world_fmt * world, long g);
 /* private functions */
 void new_localtimelist (timelist_fmt ** ntl, timelist_fmt * otl, long numpop);
-void new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world);
+void new_proposal (proposal_fmt ** proposal, timelist_fmt * tl,
+		   world_fmt * world);
 void chooseOrigin (proposal_fmt * proposal);
-void construct_localtimelist (timelist_fmt * timevector, proposal_fmt * proposal);
-void traverseAllNodes (node * theNode, node *** nodelist, long *node_elem, long *oldnode_elem, int include_migration);
+void construct_localtimelist (timelist_fmt * timevector,
+			      proposal_fmt * proposal);
+void traverseAllNodes (node * theNode, node *** nodelist, long *node_elem,
+		       long *oldnode_elem, int include_migration);
 void add_locallineages (timelist_fmt * timevector, proposal_fmt * proposal);
-void chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector, node ** bordernodes, long *bordernum);
-void findbordernodes (node * theNode, proposal_fmt * proposal, long pop, node ** bordernodes, long *bordernum, vtlist ** tyme, long gte);
+void chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector,
+		   node ** bordernodes, long *bordernum);
+void findbordernodes (node * theNode, proposal_fmt * proposal, long pop,
+		      node ** bordernodes, long *bordernum, vtlist ** tyme,
+		      long gte);
 void free_proposal (proposal_fmt * proposal);
 void free_timevector (timelist_fmt * timevector);
 long remove_doublettes (timelist_fmt * timevector, node ** ptr);
 long xor (node ** ptrl1, node ** ptrl2);
 long rmigrcount (proposal_fmt * proposal);
 
-int migrate_old (proposal_fmt * proposal, node * up, long *old_migr_table_counter, boolean air);
+int migrate_old (proposal_fmt * proposal, node * up,
+		 long *old_migr_table_counter, boolean air);
 int migrate (proposal_fmt * proposal, node * up);
 int migrateb (proposal_fmt * proposal, node * up);
 
-int pre_population (proposal_fmt * proposal, vtlist * ltime, long gte, long *slider);
+int pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
+		    long *slider);
 
-boolean acceptlike (world_fmt * world, proposal_fmt * proposal, long g, timelist_fmt * tyme);
-double eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event);
+boolean acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
+		    timelist_fmt * tyme);
+double eventtime (proposal_fmt * proposal, long pop, vtlist * tentry,
+		  char *event);
 node *showsister (node * theNode);
 void count_migrations (node * p, long *count);
 long migration_from (long to, proposal_fmt * proposal);
@@ -105,8 +115,8 @@ metropolize (world_fmt * world, long g)
   proposal_fmt *proposal;	/*scratchpad  in which all involved nodes
 				   are recorded and help arrays, e.g. migration arrays,
 				   are stored */
-  timelist_fmt *timevector=NULL;	/* local timelist */
-  vtlist *tentry=NULL;		/*pointer into timeslice */
+  timelist_fmt *timevector = NULL;	/* local timelist */
+  vtlist *tentry = NULL;	/*pointer into timeslice */
 
   /* ---------------------------------------------------------
      initialize local timelist and construct residual timelist 
@@ -145,7 +155,10 @@ metropolize (world_fmt * world, long g)
   slider = 0;
   while (nexttime <= endtime)
     {
-      actualpop = (proposal->migr_table_counter > 0) ? proposal->migr_table[proposal->migr_table_counter - 1].from : proposal->origin->pop;
+      actualpop =
+	(proposal->migr_table_counter >
+	 0) ? proposal->migr_table[proposal->migr_table_counter -
+				   1].from : proposal->origin->pop;
       proposal->time = age + eventtime (proposal, actualpop, tentry, &event);
       if (proposal->time < nexttime)
 	{
@@ -162,7 +175,8 @@ metropolize (world_fmt * world, long g)
 	    }
 	  else
 	    {			/*coalesce */
-	      chooseTarget (proposal, timevector, proposal->bordernodes, &bordernum);
+	      chooseTarget (proposal, timevector, proposal->bordernodes,
+			    &bordernum);
 	      pretendcoalesce1p (proposal);
 #ifdef UEP
 	      uepsuccess = is_success_pseudo_uep (proposal);
@@ -177,7 +191,8 @@ metropolize (world_fmt * world, long g)
     }
   if (!coalesced)
     {
-      if (!pre_population (proposal, (*timevector).tl, (*timevector).T - 1, &slider))
+      if (!pre_population
+	  (proposal, (*timevector).tl, (*timevector).T - 1, &slider))
 	{
 	  free_proposal (proposal);
 	  free_timevector (timevector);
@@ -191,23 +206,24 @@ metropolize (world_fmt * world, long g)
     }
   if (
 #ifdef UEP
-       ((!world->options->uep && !uepsuccess) || (world->options->uep && uepsuccess)) &&
+       ((!world->options->uep && !uepsuccess)
+	|| (world->options->uep && uepsuccess)) &&
 #endif
        (acceptlike (world, proposal, g, timevector)))
     {
       if (proposal->time > world->root->tyme)
 	{			/*saveguard */
 	  world->root->tyme += proposal->time;
-	}							       
+	}
       coalesce1p (proposal);
 #ifdef UEP
       world->likelihood[g] = treelikelihood (world);
-      if(world->options->uep)
+      if (world->options->uep)
 	{
 	  update_uep (world->root->next->back, world);
-	  check_uep_root(world->root->next->back, world);
+	  check_uep_root (world->root->next->back, world);
 	  world->treelen = 0.0;
-	  calc_treelength(world->root->next->back,&world->treelen);
+	  calc_treelength (world->root->next->back, &world->treelen);
 	  world->ueplikelihood = ueplikelihood (world);
 	  world->likelihood[g] = world->ueplikelihood + world->likelihood[g];
 	}
@@ -246,7 +262,7 @@ new_localtimelist (timelist_fmt ** ntl, timelist_fmt * otl, long numpop)
   for (i = 0; i < (*ntl)->allocT; i++)
     {
       (*ntl)->tl[i].lineages = (long *) calloc (numpop, sizeof (long));
-      memcpy ((*ntl)->tl[i].lineages, otl->tl[i].lineages, 
+      memcpy ((*ntl)->tl[i].lineages, otl->tl[i].lineages,
 	      numpop * sizeof (long));
     }
 }
@@ -259,8 +275,10 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
   (*proposal) = (proposal_fmt *) calloc (1, sizeof (proposal_fmt));
   (*proposal)->listsize = ((*tl).allocT + (*tl).T + 5);
 
-  (*proposal)->aboveorigin = (node **) calloc (1, sizeof (node *) * (*proposal)->listsize);
-  (*proposal)->bordernodes = (node **) calloc (1, sizeof (node *) * (*proposal)->listsize);
+  (*proposal)->aboveorigin =
+    (node **) calloc (1, sizeof (node *) * (*proposal)->listsize);
+  (*proposal)->bordernodes =
+    (node **) calloc (1, sizeof (node *) * (*proposal)->listsize);
   (*proposal)->world = world;
   (*proposal)->datatype = world->options->datatype;
   (*proposal)->sumtips = world->sumtips;
@@ -270,18 +288,24 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
   (*proposal)->param0 = world->param0;
   (*proposal)->root = world->root;
   (*proposal)->migration_model = world->options->migration_model;
-  (*proposal)->line_f = (node **) calloc (1, sizeof (node *) * (*proposal)->sumtips);
-  (*proposal)->line_t = (node **) calloc (1, sizeof (node *) * (*proposal)->sumtips);
-  (*proposal)->mf = (double *) calloc((*proposal)->endsite,sizeof(double));
-  (*proposal)->mt = (double *) calloc((*proposal)->endsite,sizeof(double));
+  (*proposal)->line_f =
+    (node **) calloc (1, sizeof (node *) * (*proposal)->sumtips);
+  (*proposal)->line_t =
+    (node **) calloc (1, sizeof (node *) * (*proposal)->sumtips);
+  (*proposal)->mf = (double *) calloc ((*proposal)->endsite, sizeof (double));
+  (*proposal)->mt = (double *) calloc ((*proposal)->endsite, sizeof (double));
   if (strchr (SEQUENCETYPES, (*proposal)->datatype))
     {
-      (*proposal)->xf.s = (phenotype) malloc (world->data->seq->endsite * sizeof (ratelike *));
-      (*proposal)->xt.s = (phenotype) malloc (world->data->seq->endsite * sizeof (ratelike *));
+      (*proposal)->xf.s =
+	(phenotype) malloc (world->data->seq->endsite * sizeof (ratelike *));
+      (*proposal)->xt.s =
+	(phenotype) malloc (world->data->seq->endsite * sizeof (ratelike *));
       for (j = 0; j < (*proposal)->endsite; j++)
 	{
-	  (*proposal)->xf.s[j] = (ratelike) malloc (world->options->rcategs * sizeof (sitelike));
-	  (*proposal)->xt.s[j] = (ratelike) malloc (world->options->rcategs * sizeof (sitelike));
+	  (*proposal)->xf.s[j] =
+	    (ratelike) malloc (world->options->rcategs * sizeof (sitelike));
+	  (*proposal)->xt.s[j] =
+	    (ratelike) malloc (world->options->rcategs * sizeof (sitelike));
 	}
     }
   else
@@ -291,8 +315,13 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
     }
   (*proposal)->old_migr_table_counter = 4 * (*proposal)->sumtips /* 100 */ ;
   (*proposal)->old_migr_table_counter2 = 4 * (*proposal)->sumtips /* 100 */ ;
-  (*proposal)->migr_table = (migr_table_fmt *) calloc (1, sizeof (migr_table_fmt) * (*proposal)->old_migr_table_counter);
-  (*proposal)->migr_table2 = (migr_table_fmt *) calloc ((*proposal)->old_migr_table_counter2, sizeof (migr_table_fmt));
+  (*proposal)->migr_table =
+    (migr_table_fmt *) calloc (1,
+			       sizeof (migr_table_fmt) *
+			       (*proposal)->old_migr_table_counter);
+  (*proposal)->migr_table2 =
+    (migr_table_fmt *) calloc ((*proposal)->old_migr_table_counter2,
+			       sizeof (migr_table_fmt));
   (*proposal)->migr_table_counter = 0;
   (*proposal)->migr_table_counter2 = 0;
   // precalculated values
@@ -301,8 +330,11 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
 #ifdef UEP
   if (world->options->uep)
     {
-      (*proposal)->ueplike = (double **) calloc (world->data->uepsites, sizeof (double *));
-      (*proposal)->ueplike[0] = (double *) calloc (world->numpop * world->data->uepsites, sizeof (double));
+      (*proposal)->ueplike =
+	(double **) calloc (world->data->uepsites, sizeof (double *));
+      (*proposal)->ueplike[0] =
+	(double *) calloc (world->numpop * world->data->uepsites,
+			   sizeof (double));
       for (j = 1; j < world->data->uepsites; ++j)
 	(*proposal)->ueplike[j] = (*proposal)->ueplike[0] + j * world->numpop;
     }
@@ -335,7 +367,8 @@ chooseOrigin (proposal_fmt * proposal)
   long elem = 0, oldelem = (proposal->sumtips * 2);
   node *tmp, **goal;
   goal = (node **) calloc (1, sizeof (node *) * oldelem);
-  traverseAllNodes (crawlback (proposal->root->next), &goal, &elem, &oldelem, NO_MIGR_NODES);
+  traverseAllNodes (crawlback (proposal->root->next), &goal, &elem, &oldelem,
+		    NO_MIGR_NODES);
   tmp = goal[RANDINT (0, elem - 2)];
   proposal->origin = tmp;
   if (proposal->origin != showtop (crawlback (proposal->root->next)))
@@ -362,7 +395,8 @@ construct_localtimelist (timelist_fmt * timevector, proposal_fmt * proposal)
   long z = 0;
   long oz = proposal->listsize;
   timevector->numpop = proposal->numpop;
-  traverseAllNodes (crawlback (proposal->origin)->back, &proposal->aboveorigin, &z, &oz, WITH_MIGR_NODES);
+  traverseAllNodes (crawlback (proposal->origin)->back,
+		    &proposal->aboveorigin, &z, &oz, WITH_MIGR_NODES);
   proposal->aboveorigin[z++] = proposal->oback;
   z = remove_doublettes (timevector, proposal->aboveorigin);
   qsort ((void *) (*timevector).tl, (*timevector).T, sizeof (vtlist), agecmp);
@@ -384,7 +418,8 @@ the macros NO_MIGR_NODES=0 and WITH_MIGR_NODES=1 in the treesetup.h file
 PB 1995
  */
 void
-traverseAllNodes (node * theNode, node *** nodelist, long *node_elem, long *oldnode_elem, int include_migration)
+traverseAllNodes (node * theNode, node *** nodelist, long *node_elem,
+		  long *oldnode_elem, int include_migration)
 {
   long elem;
   if (include_migration == NO_MIGR_NODES)
@@ -392,14 +427,18 @@ traverseAllNodes (node * theNode, node *** nodelist, long *node_elem, long *oldn
       if (theNode->type != 't')
 	{
 	  if (crawlback (theNode->next) != NULL)
-	    traverseAllNodes (crawlback (theNode->next), nodelist, node_elem, oldnode_elem, NO_MIGR_NODES);
+	    traverseAllNodes (crawlback (theNode->next), nodelist, node_elem,
+			      oldnode_elem, NO_MIGR_NODES);
 	  if (theNode->type != 'm' && crawlback (theNode->next->next) != NULL)
-	    traverseAllNodes (crawlback (theNode->next->next), nodelist, node_elem, oldnode_elem, NO_MIGR_NODES);
+	    traverseAllNodes (crawlback (theNode->next->next), nodelist,
+			      node_elem, oldnode_elem, NO_MIGR_NODES);
 	  if ((*node_elem) == (*oldnode_elem - 1))
 	    {
 	      elem = *oldnode_elem = ((*oldnode_elem) + (*oldnode_elem) / 2);
-	      (*nodelist) = (node **) realloc ((*nodelist), sizeof (node *) * elem);
-	      memset ((*nodelist) + (*oldnode_elem), 0, sizeof (node *) * (elem - (*oldnode_elem)));
+	      (*nodelist) =
+		(node **) realloc ((*nodelist), sizeof (node *) * elem);
+	      memset ((*nodelist) + (*oldnode_elem), 0,
+		      sizeof (node *) * (elem - (*oldnode_elem)));
 	      *oldnode_elem = elem;
 	    }
 	  (*nodelist)[(*node_elem)++] = theNode;
@@ -413,8 +452,10 @@ traverseAllNodes (node * theNode, node *** nodelist, long *node_elem, long *oldn
 	  if ((*node_elem) == (*oldnode_elem - 1))
 	    {
 	      elem = *oldnode_elem = ((*oldnode_elem) + (*oldnode_elem) / 2);
-	      (*nodelist) = (node **) realloc ((*nodelist), sizeof (node *) * elem);
-	      memset ((*nodelist) + (*oldnode_elem), 0, sizeof (node *) * (elem - (*oldnode_elem)));
+	      (*nodelist) =
+		(node **) realloc ((*nodelist), sizeof (node *) * elem);
+	      memset ((*nodelist) + (*oldnode_elem), 0,
+		      sizeof (node *) * (elem - (*oldnode_elem)));
 	      *oldnode_elem = elem;
 	    }
 	  (*nodelist)[(*node_elem)] = theNode;
@@ -426,14 +467,18 @@ traverseAllNodes (node * theNode, node *** nodelist, long *node_elem, long *oldn
       if (theNode->type != 't')
 	{
 	  if (theNode->next->back != NULL)
-	    traverseAllNodes (theNode->next->back, nodelist, node_elem, oldnode_elem, WITH_MIGR_NODES);
+	    traverseAllNodes (theNode->next->back, nodelist, node_elem,
+			      oldnode_elem, WITH_MIGR_NODES);
 	  if (theNode->type != 'm' && theNode->next->next->back != NULL)
-	    traverseAllNodes (theNode->next->next->back, nodelist, node_elem, oldnode_elem, WITH_MIGR_NODES);
+	    traverseAllNodes (theNode->next->next->back, nodelist, node_elem,
+			      oldnode_elem, WITH_MIGR_NODES);
 	  if ((*node_elem) == (*oldnode_elem - 1))
 	    {
 	      elem = *oldnode_elem = ((*oldnode_elem) + (*oldnode_elem) / 2);
-	      (*nodelist) = (node **) realloc ((*nodelist), sizeof (node *) * elem);
-	      memset ((*nodelist) + (*oldnode_elem), 0, sizeof (node *) * (elem - (*oldnode_elem)));
+	      (*nodelist) =
+		(node **) realloc ((*nodelist), sizeof (node *) * elem);
+	      memset ((*nodelist) + (*oldnode_elem), 0,
+		      sizeof (node *) * (elem - (*oldnode_elem)));
 	      *oldnode_elem = elem;
 	    }
 	  (*nodelist)[(*node_elem)++] = theNode;
@@ -443,8 +488,10 @@ traverseAllNodes (node * theNode, node *** nodelist, long *node_elem, long *oldn
 	  if ((*node_elem) == (*oldnode_elem - 1))
 	    {
 	      elem = *oldnode_elem = ((*oldnode_elem) + (*oldnode_elem) / 2);
-	      (*nodelist) = (node **) realloc ((*nodelist), sizeof (node *) * elem);
-	      memset ((*nodelist) + (*oldnode_elem), 0, sizeof (node *) * (elem - (*oldnode_elem)));
+	      (*nodelist) =
+		(node **) realloc ((*nodelist), sizeof (node *) * elem);
+	      memset ((*nodelist) + (*oldnode_elem), 0,
+		      sizeof (node *) * (elem - (*oldnode_elem)));
 	      *oldnode_elem = elem;
 	    }
 	  (*nodelist)[(*node_elem)++] = theNode;
@@ -483,7 +530,8 @@ add_locallineages (timelist_fmt * timevector, proposal_fmt * proposal)
   if (timevector->T == 1)
     timevector->tl[0].lineages[proposal->osister->actualpop] += 1;
   else
-    timevector->tl[timevector->T - 1].lineages[timevector->tl[timevector->T - 2].from] += 1;
+    timevector->tl[timevector->T -
+		   1].lineages[timevector->tl[timevector->T - 2].from] += 1;
   add_partlineages (numpop, &timevector);
 
 }
@@ -540,7 +588,10 @@ migrate (proposal_fmt * proposal, node * up)
   if (i >= proposal->old_migr_table_counter)
     {
       proposal->old_migr_table_counter += 10;
-      proposal->migr_table = (migr_table_fmt *) realloc (proposal->migr_table, sizeof (migr_table_fmt) * (proposal->old_migr_table_counter));
+      proposal->migr_table =
+	(migr_table_fmt *) realloc (proposal->migr_table,
+				    sizeof (migr_table_fmt) *
+				    (proposal->old_migr_table_counter));
     }
   proposal->migr_table_counter = i;
   return 1;
@@ -566,14 +617,18 @@ migrateb (proposal_fmt * proposal, node * up)
   if (i >= proposal->old_migr_table_counter2)
     {
       proposal->old_migr_table_counter2 += 10;
-      proposal->migr_table2 = (migr_table_fmt *) realloc (proposal->migr_table2, sizeof (migr_table_fmt) * (proposal->old_migr_table_counter2));
+      proposal->migr_table2 =
+	(migr_table_fmt *) realloc (proposal->migr_table2,
+				    sizeof (migr_table_fmt) *
+				    (proposal->old_migr_table_counter2));
     }
   proposal->migr_table_counter2 = i;
   return 1;
 }
 
 int
-migrate_old (proposal_fmt * proposal, node * up, long *old_migr_table_counter, boolean air)
+migrate_old (proposal_fmt * proposal, node * up, long *old_migr_table_counter,
+	     boolean air)
 {
   migr_table_fmt *array;
   long i;
@@ -620,12 +675,18 @@ migrate_old (proposal_fmt * proposal, node * up, long *old_migr_table_counter, b
       (*old_migr_table_counter) += 10;
       if (air)
 	{
-	  proposal->migr_table = (migr_table_fmt *) realloc (proposal->migr_table, sizeof (migr_table_fmt) * (*old_migr_table_counter));
+	  proposal->migr_table =
+	    (migr_table_fmt *) realloc (proposal->migr_table,
+					sizeof (migr_table_fmt) *
+					(*old_migr_table_counter));
 	  array = proposal->migr_table;
 	}
       else
 	{
-	  proposal->migr_table2 = (migr_table_fmt *) realloc (proposal->migr_table2, sizeof (migr_table_fmt) * (*old_migr_table_counter));
+	  proposal->migr_table2 =
+	    (migr_table_fmt *) realloc (proposal->migr_table2,
+					sizeof (migr_table_fmt) *
+					(*old_migr_table_counter));
 	  array = proposal->migr_table;
 	}
     }
@@ -673,7 +734,7 @@ migration_from_old (long to, proposal_fmt * proposal)
 long
 migration_from (long to, proposal_fmt * proposal)
 {
-  long ii=0;
+  long ii = 0;
   double *r = proposal->world->migproblist[to];
   double rr = RANDUM ();
   while (rr > r[ii])
@@ -687,7 +748,8 @@ migration_from (long to, proposal_fmt * proposal)
 }
 
 void
-chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector, node ** bordernodes, long *bordernum)
+chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector,
+	      node ** bordernodes, long *bordernum)
 {
   long actualpop = -99;
   node *rb = crawlback (proposal->root->next);
@@ -702,7 +764,8 @@ chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector, node ** border
     {
       error ("Wrong Time for action in chooseTarget()\n");
     }
-  findbordernodes (rb, proposal, actualpop, bordernodes, bordernum, &(*timevector).tl, (*timevector).T);
+  findbordernodes (rb, proposal, actualpop, bordernodes, bordernum,
+		   &(*timevector).tl, (*timevector).T);
   if (*bordernum > 0)
     {
       proposal->target = bordernodes[RANDINT (0, (*bordernum) - 1)];
@@ -727,7 +790,9 @@ chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector, node ** border
 }
 
 void
-findbordernodes (node * theNode, proposal_fmt * proposal, long pop, node ** bordernodes, long *bordernum, vtlist ** tyme, long gte)
+findbordernodes (node * theNode, proposal_fmt * proposal, long pop,
+		 node ** bordernodes, long *bordernum, vtlist ** tyme,
+		 long gte)
 {
   node *tmp, *back;
   if (theNode == proposal->oback)
@@ -740,7 +805,8 @@ findbordernodes (node * theNode, proposal_fmt * proposal, long pop, node ** bord
       tmp = showtop (theNode);
       back = showtop (theNode->back);
     }
-  if (pop == tmp->pop && pop == back->actualpop && tmp->tyme < proposal->time && back->tyme > proposal->time)
+  if (pop == tmp->pop && pop == back->actualpop && tmp->tyme < proposal->time
+      && back->tyme > proposal->time)
     {
       bordernodes[(*bordernum)++] = tmp;
       return;
@@ -752,9 +818,11 @@ findbordernodes (node * theNode, proposal_fmt * proposal, long pop, node ** bord
       if (tmp->type != 't')
 	{
 	  if (tmp->next->back != NULL)
-	    findbordernodes (tmp->next->back, proposal, pop, bordernodes, bordernum, tyme, gte);
+	    findbordernodes (tmp->next->back, proposal, pop, bordernodes,
+			     bordernum, tyme, gte);
 	  if (tmp->type != 'm' && tmp->next->next->back != NULL)
-	    findbordernodes (tmp->next->next->back, proposal, pop, bordernodes, bordernum, tyme, gte);
+	    findbordernodes (tmp->next->next->back, proposal, pop,
+			     bordernodes, bordernum, tyme, gte);
 	}
     }
 }
@@ -780,7 +848,8 @@ findbordernodes (node * theNode, proposal_fmt * proposal, long pop, node ** bord
 /* -----------------------------------------------------------------------
    simulates two lineages at once, if we are extending below the last node */
 int
-pre_population (proposal_fmt * proposal, vtlist * ltime, long gte, long *slider)
+pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
+		long *slider)
 {
   boolean coalesced = FALSE;
   boolean choice = FALSE;
@@ -810,8 +879,15 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte, long *slider)
     }
   proposal->tsister = NULL;
   pop2 = proposal->realtarget->pop;
-  pop1 = proposal->migr_table_counter > 0 ? proposal->migr_table[proposal->migr_table_counter - 1].from : proposal->origin->pop;
-  age1 = MAX (proposal->realtarget->tyme, proposal->migr_table_counter > 0 ? proposal->migr_table[proposal->migr_table_counter - 1].time : proposal->origin->tyme);
+  pop1 =
+    proposal->migr_table_counter >
+    0 ? proposal->migr_table[proposal->migr_table_counter -
+			     1].from : proposal->origin->pop;
+  age1 =
+    MAX (proposal->realtarget->tyme,
+	 proposal->migr_table_counter >
+	 0 ? proposal->migr_table[proposal->migr_table_counter -
+				  1].time : proposal->origin->tyme);
   horizon = MAX (proposal->oback->tyme, age1);
   while (age1 < horizon)
     {
@@ -851,7 +927,10 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte, long *slider)
 	    {
 	      return 0;
 	    }
-	  pop1 = proposal->migr_table_counter > 0 ? proposal->migr_table[proposal->migr_table_counter - 1].from : proposal->origin->pop;
+	  pop1 =
+	    proposal->migr_table_counter >
+	    0 ? proposal->migr_table[proposal->migr_table_counter -
+				     1].from : proposal->origin->pop;
 	}
     }
   age1 = horizon;
@@ -917,7 +996,10 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte, long *slider)
 	    {
 	      return 0;		/* migration limit reached */
 	    }
-	  pop1 = proposal->migr_table_counter > 0 ? proposal->migr_table[proposal->migr_table_counter - 1].from : proposal->origin->pop;
+	  pop1 =
+	    proposal->migr_table_counter >
+	    0 ? proposal->migr_table[proposal->migr_table_counter -
+				     1].from : proposal->origin->pop;
 	}
       else
 	{
@@ -927,7 +1009,10 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte, long *slider)
 	    {
 	      return 0;		/* migration limit reached */
 	    }
-	  pop2 = proposal->migr_table_counter2 > 0 ? proposal->migr_table2[proposal->migr_table_counter2 - 1].from : proposal->realtarget->pop;
+	  pop2 =
+	    proposal->migr_table_counter2 >
+	    0 ? proposal->migr_table2[proposal->migr_table_counter2 -
+				      1].from : proposal->realtarget->pop;
 	}
     }
   error ("Reached the end of function without coalescing");
@@ -989,7 +1074,8 @@ free_timevector (timelist_fmt * timevector)
  * likelihood values are (-> Metropolis)
  */
 boolean
-acceptlike (world_fmt * world, proposal_fmt * proposal, long g, timelist_fmt * tyme)
+acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
+	    timelist_fmt * tyme)
 {
 #ifdef UEP
   node *first;
@@ -1001,13 +1087,15 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g, timelist_fmt * t
   long rm;
   long rmc = rmigrcount (proposal);
   zz = world->heat;
-  if ((rm = proposal->migr_table_counter + proposal->migr_table_counter2 + world->migration_counts - rmc) > MIGRATION_LIMIT * world->numpop)
+  if ((rm =
+       proposal->migr_table_counter + proposal->migr_table_counter2 +
+       world->migration_counts - rmc) > MIGRATION_LIMIT * world->numpop)
     {
       if (report || g != oldg)
 	{
-	  warning ("migration limit (%li) exceeded: %li\n", MIGRATION_LIMIT * world->numpop, rm);
-	  warning ("results may be underestimating migration rates\n");
-	  warning ("for this chain\n");
+	  warning ("migration limit (%li) exceeded: %li\n",
+		   MIGRATION_LIMIT * world->numpop, rm);
+	  warning ("results may be underestimating migration rates for this chain\n");
 	  report = FALSE;
 	  oldg = g;
 	}
@@ -1016,8 +1104,12 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g, timelist_fmt * t
 #ifdef UEP
   if (world->options->uep)
     {
-      first = first_uep2 (proposal->world->root->next->back, proposal->world->root->next->back, proposal->world->data->uepsites);
-      proposal->firstuep = first_uep (first, NULL, proposal->world->data->uepsites);
+      first =
+	first_uep2 (proposal->world->root->next->back,
+		    proposal->world->root->next->back,
+		    proposal->world->data->uepsites);
+      proposal->firstuep =
+	first_uep (first, NULL, proposal->world->data->uepsites);
       proposal->ueplikelihood = pseudo_ueplikelihood (world, proposal);
       proposal->likelihood = pseudotreelikelihood (world, proposal);
       //      printf("%s> pl=%f pul=%f\n",proposal->world->name,proposal->likelihood,proposal->ueplikelihood);
@@ -1099,7 +1191,8 @@ eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
 		      if (mig_force)
 			{
 			  warning ("Migration forced\n");
-			  warning ("results may be overestimating migration rates\n");
+			  warning
+			    ("results may be overestimating migration rates\n");
 			  warning ("for this chain\n");
 			  mig_force = FALSE;
 			}
@@ -1182,7 +1275,9 @@ prob_tree (world_fmt * world, timelist_fmt * tyme)
       for (pop = 0; pop < world->numpop; pop++)
 	{
 	  mm += tyme->tl[j].lineages[pop] * world->mig0list[pop];
-	  cc += tyme->tl[j].lineages[pop] * (tyme->tl[j].lineages[pop] - 1) / world->param0[pop];
+	  cc +=
+	    tyme->tl[j].lineages[pop] * (tyme->tl[j].lineages[pop] -
+					 1) / world->param0[pop];
 	}
       ss += -(tyme->tl[j].interval) * (mm + cc);
       if (tyme->tl[j].from == tyme->tl[j].to)
