@@ -10,7 +10,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: profile.c,v 1.53 2001/07/16 16:03:21 beerli Exp $
+$Id: profile.c,v 1.54 2001/07/25 19:27:24 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -31,34 +31,48 @@ $Id: profile.c,v 1.53 2001/07/16 16:03:21 beerli Exp $
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
-long find_profilelike (double testlike, long whichprob, double minparam, double maxparam, double *param, double *llike, long which, world_fmt * world, boolean QD, boolean QD2, double *mlparam, double *normd, nr_fmt *nr);
-void calc_profile_likelihood (char method, long which, double *likes, double **param, world_fmt * world, long nn, nr_fmt *nr);
+long find_profilelike (double testlike, long whichprob, double minparam,
+		       double maxparam, double *param, double *llike,
+		       long which, world_fmt * world, boolean QD, boolean QD2,
+		       double *mlparam, double *normd, nr_fmt * nr);
+void calc_profile_likelihood (char method, long which, double *likes,
+			      double **param, world_fmt * world, long nn,
+			      nr_fmt * nr);
 void print_profile_likelihood (long which, world_fmt * world, long *gmaxptr);
 void prepare_header (char *var, long which, world_fmt * world);
 void print_profile_title (world_fmt * world);
-void print_profile_table (char method, long which, char *var, double *likes, double **param, world_fmt * world);
+void print_profile_table (char method, long which, char *var, double *likes,
+			  double **param, world_fmt * world);
 void print_profile_percentile (world_fmt * world);
 void print_percentile_header (FILE * outfile, boolean first);
 void allocate_profile_percentiles (world_fmt * world);
 void destroy_profile_percentiles (world_fmt * world);
 void print_menu_profile (long which, long nn);
-double interpolate (double xl, double xc, double xh, double low, double center, double high, double testlike);
+double interpolate (double xl, double xc, double xh, double low,
+		    double center, double high, double testlike);
 
 long warp (long ii);
 
 void prognose_profile_end (time_t starttime, long numpop2, long nn);
 
 
-void profile_max_percentiles (long which, double *likes, double **param, world_fmt * world, long nn, nr_fmt *nr);
+void profile_max_percentiles (long which, double *likes, double **param,
+			      world_fmt * world, long nn, nr_fmt * nr);
 
-void profile_max_spline (char method, long which, double *likes, double **param, world_fmt * world, nr_fmt *nr, long nn);
+void profile_max_spline (char method, long which, double *likes,
+			 double **param, world_fmt * world, nr_fmt * nr,
+			 long nn);
 
-int calc_spline (double *param, double *like, long nn, long *constr, double *diff, double *diff2, long *diagn, double *work, long nwork);
+int calc_spline (double *param, double *like, long nn, long *constr,
+		 double *diff, double *diff2, long *diagn, double *work,
+		 long nwork);
 void setup_spline (spline_fmt * spline);
 
 void destroy_spline (spline_fmt * spline);
 
-void prepare_spline_nodes (long n, long which, double **rawparam, double *rawlikes, long *indeks, double *param, double *likes);
+void prepare_spline_nodes (long n, long which, double **rawparam,
+			   double *rawlikes, long *indeks, double *param,
+			   double *likes);
 
 void prepare_spline_first (double *param, double *likes);
 
@@ -66,15 +80,20 @@ void prepare_spline_last (long n, double *param, double *likes);
 
 void calc_spline_diff (double *diff, double *param, double *likes, long n);
 
-double recalc_profilelike (double testparam, double *param, double *like, long nn, double *diff, double *diff2, double *work, long nwork);
+double recalc_profilelike (double testparam, double *param, double *like,
+			   long nn, double *diff, double *diff2, double *work,
+			   long nwork);
 
 
 long set_df (long which, char *custm2, long numpop, long numpop2);
 
 
-long set_profile_param (double *param, long which, long *allwhich, double xval, double *xvals, world_fmt * world);
-void addinvar (double *param, long *fixed, long *allwhich, double *xvals, long start, long len);
-void print_nice_param (double parameter, double bottom, double top, FILE * file);
+long set_profile_param (double *param, long which, long *allwhich,
+			double xval, double *xvals, world_fmt * world);
+void addinvar (double *param, long *fixed, long *allwhich, double *xvals,
+	       long start, long len);
+void print_nice_param (double parameter, double bottom, double top,
+		       FILE * file);
 
 
 
@@ -88,12 +107,13 @@ void print_nice_param (double parameter, double bottom, double top, FILE * file)
 //#define DEVIATE {0.002,0.010,0.020, 0.05, 5000.,1000., 500., 200., 1.}
 #define ABSOLUTE {1e-100,1e100}
 
-boolean print_profile_likelihood_driver (long which, world_fmt * world, long *gmaxptr)
+boolean
+print_profile_likelihood_driver (long which, world_fmt * world, long *gmaxptr)
 {
   static boolean onetheta = FALSE;
   static boolean onemig = FALSE;
   long i, j;
-  world->options->verbose=FALSE; 
+  world->options->verbose = FALSE;
 
   if (which == world->numpop2)	//gamma deviated mutation rate
     print_profile_likelihood (which, world, gmaxptr);
@@ -148,10 +168,10 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
   char method = world->options->profilemethod;
   double **param;
   double likes[GRIDSIZE];
-  long elem = world->options->gamma ? world->numpop * world->numpop + 1 : 
+  long elem = world->options->gamma ? world->numpop * world->numpop + 1 :
     world->numpop * world->numpop;
-  nr = (nr_fmt *) calloc(1,sizeof(nr_fmt));
-  create_nr (nr, world, *gmaxptr, which, world->loci, 
+  nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
+  create_nr (nr, world, *gmaxptr, which, world->loci,
 	     world->repkind, world->rep);
   param = (double **) calloc (1, sizeof (double *) * GRIDSIZE);
   param[0] = (double *) calloc (1, sizeof (double) * GRIDSIZE * elem);
@@ -161,7 +181,8 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
     }
   if (world->options->progress)
     {
-      print_menu_profile (which, world->numpop2 + (long) world->options->gamma);
+      print_menu_profile (which,
+			  world->numpop2 + (long) world->options->gamma);
     }
   calc_profile_likelihood (method, which, likes, param, world, GRIDSIZE, nr);
 
@@ -179,26 +200,35 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
 	  world->quantiles[which].param[i] = param[i][which];
 	}
     }
-  destroy_nr(nr,world);
+  destroy_nr (nr, world);
   free (param[0]);
   free (param);
 }
 
 void
-print_profile_table (char method, long which, char *var, double *likes, double **param, world_fmt * world)
+print_profile_table (char method, long which, char *var, double *likes,
+		     double **param, world_fmt * world)
 {
   const double probabilities[] = SHOWGRID;
   char star;
   char methodstring[LINESIZE];
   long i, ii, j, likei = 0;
-  long elem = world->options->gamma ? world->numpop * world->numpop + 1 : world->numpop * world->numpop;
+  long elem =
+    world->options->gamma ? world->numpop * world->numpop +
+    1 : world->numpop * world->numpop;
 
   FILE *outfile = world->outfile;
   char *temp, *var2, temp2[LINESIZE], likestr[LINESIZE], *paramstr;
   double likemax = -DBL_MAX;
 
-  var2 = (char *) calloc (1, sizeof (char) * MAX (LINESIZE, (long)(elem / 10. * LINESIZE)));
-  paramstr = (char *) calloc (1, sizeof (char) * MAX (LINESIZE, (long)(elem / 10. * LINESIZE)));
+  var2 =
+    (char *) calloc (1,
+		     sizeof (char) * MAX (LINESIZE,
+					  (long) (elem / 10. * LINESIZE)));
+  paramstr =
+    (char *) calloc (1,
+		     sizeof (char) * MAX (LINESIZE,
+					  (long) (elem / 10. * LINESIZE)));
   temp = var2;
   for (j = 0; j < elem; j++)
     {
@@ -209,7 +239,8 @@ print_profile_table (char method, long which, char *var, double *likes, double *
 	star = ' ';
       if (((j + 1) % 5) == 0)
 	{
-	  sprintf (temp, "\n                            %c%.7s%c     ", star, temp2, star);
+	  sprintf (temp, "\n                            %c%.7s%c     ", star,
+		   temp2, star);
 	  temp += 28;
 	}
       else
@@ -219,19 +250,24 @@ print_profile_table (char method, long which, char *var, double *likes, double *
   switch (method)
     {
     case 'p':
-      strcpy (methodstring, "Parameters are evaluated at percentiles\nusing bisection method (slow, but exact).");
+      strcpy (methodstring,
+	      "Parameters are evaluated at percentiles\nusing bisection method (slow, but exact).");
       break;
     case 's':
-      strcpy (methodstring, "Parameters are evaluated at percentiles\nusing cubic splines of profiled parameter\n(faster, but not so exact).");
+      strcpy (methodstring,
+	      "Parameters are evaluated at percentiles\nusing cubic splines of profiled parameter\n(faster, but not so exact).");
       break;
     case 'd':
-      strcpy (methodstring, "Parameters are evaluated at pre-defined values\n");
+      strcpy (methodstring,
+	      "Parameters are evaluated at pre-defined values\n");
       break;
     case 'q':
-      strcpy (methodstring, "Parameters are evaluated assuming complete independence\n");
+      strcpy (methodstring,
+	      "Parameters are evaluated assuming complete independence\n");
       break;
     case 'f':
-      strcpy (methodstring, "Parameters are evaluated assuming complete independence\n and then once maximized at the found profiled parameter value");
+      strcpy (methodstring,
+	      "Parameters are evaluated assuming complete independence\n and then once maximized at the found profiled parameter value");
       break;
     }
   fprintf (outfile, "\n\nProfile likelihood for parameter %s\n", var);
@@ -274,7 +310,7 @@ print_profile_table (char method, long which, char *var, double *likes, double *
 	      else
 		sprintf (temp, "% 10.6f ", param[i][j]);
 	    }
-	  
+
 	  temp += 11;
 	}
       if (param[i][which] <= 0)
@@ -282,29 +318,33 @@ print_profile_table (char method, long which, char *var, double *likes, double *
 	  if (method == 'd')
 	    fprintf (outfile, "        -           -       %s\n", paramstr);
 	  else
-	    fprintf (outfile, "%3.3f     -           -       %s\n", probabilities[i], paramstr);
+	    fprintf (outfile, "%3.3f     -           -       %s\n",
+		     probabilities[i], paramstr);
 	}
       else
 	{
 	  if (method == 'd')
-	    fprintf (outfile, "    %8.8s % 10.6g %s\n", likestr, param[i][which], paramstr);
+	    fprintf (outfile, "    %8.8s % 10.6g %s\n", likestr,
+		     param[i][which], paramstr);
 	  else
 	    {
-	      if(probabilities[i]==0.5)
-		fprintf (outfile, "MLE   %8.8s % 10.6g %s\n", 
-			 likestr, 
-			 param[i][which], paramstr);
+	      if (probabilities[i] == 0.5)
+		fprintf (outfile, "MLE   %8.8s % 10.6g %s\n",
+			 likestr, param[i][which], paramstr);
 	      else
-		fprintf (outfile, "%4.3f %8.8s % 10.6g %s\n", 
-			 probabilities[i], likestr, 
+		fprintf (outfile, "%4.3f %8.8s % 10.6g %s\n",
+			 probabilities[i], likestr,
 			 param[i][which], paramstr);
 	    }
 	}
     }
   print_line (outfile, '-', 79, STOP);
-  fprintf (outfile, "- = not possible to evaluate, most likely value either 0.0 or Infinity\n");
-  fprintf (outfile, "    in the parameter direction, the likelihood surface is so flat\n");
-  fprintf (outfile, "    that the calculation of the percentile(s)  failed.\n");
+  fprintf (outfile,
+	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n");
+  fprintf (outfile,
+	   "    in the parameter direction, the likelihood surface is so flat\n");
+  fprintf (outfile,
+	   "    that the calculation of the percentile(s)  failed.\n");
   free (paramstr);
   free (var2);
 }
@@ -348,7 +388,8 @@ print_profile_percentile (world_fmt * world)
   boolean last = FALSE;
   fprintf (world->outfile, "\n\n");
   print_line (world->outfile, '=', 79, CONT);
-  fprintf (world->outfile, "Summary of profile likelihood percentiles of all parameters\n");
+  fprintf (world->outfile,
+	   "Summary of profile likelihood percentiles of all parameters\n");
   print_line (world->outfile, '=', 79, CONT);
   fprintf (world->outfile, "\n");
   print_percentile_header (world->outfile, first);
@@ -365,7 +406,8 @@ print_profile_percentile (world_fmt * world)
 	  if (world->quantiles[i].param[j] < 0)
 	    fprintf (world->outfile, "      -       ");
 	  else
-	    print_nice_param (world->quantiles[i].param[j], 0.000001, 999.99999, world->outfile);
+	    print_nice_param (world->quantiles[i].param[j], 0.000001,
+			      999.99999, world->outfile);
 	}
       fprintf (world->outfile, "\n");
     }
@@ -384,16 +426,20 @@ print_profile_percentile (world_fmt * world)
 	  if (world->quantiles[i].param[j] < 0)
 	    fprintf (world->outfile, "      -       ");
 	  else
-	    print_nice_param (world->quantiles[i].param[j], 0.000001, 999.99999, world->outfile);
+	    print_nice_param (world->quantiles[i].param[j], 0.000001,
+			      999.99999, world->outfile);
 	}
       fprintf (world->outfile, "\n");
     }
 
   fprintf (world->outfile, "\n");
   print_line (world->outfile, '-', 80, CONT);
-  fprintf (world->outfile, "- = not possible to evaluate, most likely value either 0.0 or Infinity\n");
-  fprintf (world->outfile, "    in the parameter direction, the likelihood surface is so flat\n");
-  fprintf (world->outfile, "    that the percentiles cannot be calculated.\n");
+  fprintf (world->outfile,
+	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n");
+  fprintf (world->outfile,
+	   "    in the parameter direction, the likelihood surface is so flat\n");
+  fprintf (world->outfile,
+	   "    that the percentiles cannot be calculated.\n");
 }
 
 void
@@ -411,9 +457,11 @@ print_percentile_header (FILE * outfile, boolean first)
   const double probabilities[] = GRID2;
   long i;
   if (first)
-    fprintf (outfile, "Parameter                          Lower percentiles\n");
+    fprintf (outfile,
+	     "Parameter                          Lower percentiles\n");
   else
-    fprintf (outfile, "Parameter                          Upper percentiles\n");
+    fprintf (outfile,
+	     "Parameter                          Upper percentiles\n");
   fprintf (outfile, "            ");
   print_line (outfile, '-', 68, CONT);
   fprintf (outfile, "            ");
@@ -429,15 +477,15 @@ print_percentile_header (FILE * outfile, boolean first)
 	  if (probabilities[i] < 0.5)
 	    continue;
 	}
-      if(probabilities[i] == 0.5)
-	fprintf (outfile, "    MLE     ");
+      if (probabilities[i] == 0.5)
+	fprintf (outfile, "    MLE       ");
       else
-	fprintf (outfile, "    %3.3f     ", probabilities[i]);
+	fprintf (outfile, "    %5.3f     ", probabilities[i]);
     }
-  if(probabilities[i] == 0.5)
+  if (probabilities[i] == 0.5)
     fprintf (outfile, "    MLE\n");
   else
-    fprintf (outfile, "    %3.3f\n", probabilities[i]);
+    fprintf (outfile, "    %5.3f\n", probabilities[i]);
   print_line (outfile, '-', 80, CONT);
 }
 
@@ -469,7 +517,9 @@ prepare_header (char *var, long which, world_fmt * world)
 }
 
 void
-calc_profile_likelihood (char method, long which, double *likes, double **param, world_fmt * world, long nn, nr_fmt *nr)
+calc_profile_likelihood (char method, long which, double *likes,
+			 double **param, world_fmt * world, long nn,
+			 nr_fmt * nr)
 {
   long i, j;
   switch (method)
@@ -490,7 +540,8 @@ calc_profile_likelihood (char method, long which, double *likes, double **param,
 	{
 	  for (j = world->numpop; j < world->numpop2; j++)
 	    {
-	      param[i][j] *= param[i][(long) (j - world->numpop) / (world->numpop - 1)];
+	      param[i][j] *=
+		param[i][(long) (j - world->numpop) / (world->numpop - 1)];
 	    }
 	}
     }
@@ -532,7 +583,8 @@ prognose_profile_end (time_t starttime, long numpop2, long nn)
 
 
 void
-profile_max_percentiles (long which, double *likes, double **param, world_fmt * world, long nn, nr_fmt *nr)
+profile_max_percentiles (long which, double *likes, double **param,
+			 world_fmt * world, long nn, nr_fmt * nr)
 {
   const double probabilities[] = GRID;
 
@@ -541,11 +593,16 @@ profile_max_percentiles (long which, double *likes, double **param, world_fmt *
   boolean QD = FALSE, QD2 = FALSE;
   double prob, normd, maxlike, testlike, minparam = 0, maxparam = 0;
   double *mlparam;
-  long rep = world->options->replicate ? (world->loci > 1 ? 0 : world->repstop) : 0;
-  df = (world->options->df > 0) ? 
-    world->options->df : 
-    set_df (which, world->options->custm2, world->numpop, world->numpop2 
-	    + (long) world->options->gamma);
+  long rep =
+    world->options->replicate ? (world->loci > 1 ? 0 : world->repstop) : 0;
+  df =
+    (world->options->df > 0) ? world->options->df : set_df (which,
+							    world->options->
+							    custm2,
+							    world->numpop,
+							    world->numpop2 +
+							    (long) world->
+							    options->gamma);
 
   /* QD assumes that there is NO correlation between parameters
      that is certainly wrong but sometimes close and much faster
@@ -575,9 +632,10 @@ profile_max_percentiles (long which, double *likes, double **param, world_fmt *
       mlparam = world->atl[rep][world->locus].param;
       maxlike = world->atl[rep][world->locus].param_like;
     }
-  
 
-  memcpy (param[nn - 1], mlparam, sizeof (double) * (world->numpop2 + (long) world->options->gamma));
+
+  memcpy (param[nn - 1], mlparam,
+	  sizeof (double) * (world->numpop2 + (long) world->options->gamma));
   likes[nn - 1] = maxlike;
   maxparam = param[nn - 1][which];
 
@@ -592,25 +650,28 @@ profile_max_percentiles (long which, double *likes, double **param, world_fmt *
 	{
 	  minparam = param[i - 1][which];
 	  if (minparam < 0)
-	    minparam = which < world->numpop ? 
+	    minparam = which < world->numpop ?
 	      SMALLEST_THETA : SMALLEST_MIGRATION;
 	}
 #ifdef __MWERKS__
       eventloop ();
 #endif
-      memcpy (param[i], mlparam, 
-	      sizeof (double)*(world->numpop2+(long) world->options->gamma));
-      trials = find_profilelike (testlike, i, minparam, maxparam, 
-				 param[i], &likes[i], which, world, 
-				 QD, QD2, mlparam, &normd, nr);
+      memcpy (param[i], mlparam,
+	      sizeof (double) * (world->numpop2 +
+				 (long) world->options->gamma));
+      trials =
+	find_profilelike (testlike, i, minparam, maxparam, param[i],
+			  &likes[i], which, world, QD, QD2, mlparam, &normd,
+			  nr);
       if (world->options->progress)
-	prognose_profile_end (world->starttime, world->numpop2 + 
+	prognose_profile_end (world->starttime, world->numpop2 +
 			      (long) world->options->gamma, nn);
     }
 }
 
 void
-profile_max_spline (char method, long which, double *likes, double **param, world_fmt * world, nr_fmt *nr, long nn)
+profile_max_spline (char method, long which, double *likes, double **param,
+		    world_fmt * world, nr_fmt * nr, long nn)
 {
 
   double deviate[] = DEVIATE;
@@ -622,11 +683,19 @@ profile_max_spline (char method, long which, double *likes, double **param, worl
   double prob, normd, maxlike, testlike, minparam = 0, maxparam = 0;
   double *mlparam;
   double tmp, x, xx, xlow, xhigh, mid, low, high, value;
-  long rep = world->options->replicate ? (world->loci > 1 ? 0 : world->repstop) : 0;
+  long rep =
+    world->options->replicate ? (world->loci > 1 ? 0 : world->repstop) : 0;
   spline_fmt *spline;
 
   /* set degree of freedom */
-  df = (world->options->df > 0) ? world->options->df : set_df (which, world->options->custm2, world->numpop, world->numpop2 + (long) world->options->gamma);
+  df =
+    (world->options->df > 0) ? world->options->df : set_df (which,
+							    world->options->
+							    custm2,
+							    world->numpop,
+							    world->numpop2 +
+							    (long) world->
+							    options->gamma);
   /* the minimum */
   minparam = which < world->numpop ? SMALLEST_THETA : SMALLEST_MIGRATION;
   /* the maximum */
@@ -640,7 +709,8 @@ profile_max_spline (char method, long which, double *likes, double **param, worl
       mlparam = world->atl[rep][world->locus].param;
       maxlike = world->atl[rep][world->locus].param_like;
     }
-  memcpy (param[nn - 1], mlparam, sizeof (double) * (world->numpop2 + (long) world->options->gamma));
+  memcpy (param[nn - 1], mlparam,
+	  sizeof (double) * (world->numpop2 + (long) world->options->gamma));
   likes[nn - 1] = maxlike;
   maxparam = param[nn - 1][which];
   /* calculate likelihood at GRIDNODES */
@@ -650,28 +720,33 @@ profile_max_spline (char method, long which, double *likes, double **param, worl
 	value = deviate[i];
       else
 	value = deviate[i] * mlparam[which];
-      nr->profilenum = set_profile_param (param[i], which, nr->profiles, 
-					  value,
-					  nr->values, world);
+      nr->profilenum = set_profile_param (param[i], which, nr->profiles,
+					  value, nr->values, world);
       //do_profiles(nr->world, nr, likes, &normd, PROFILE, 
-      //	  nr->world->rep, nr->world->repkind);
-      maximize(param[i], world, nr, PROFILE, world->repkind);
+      //          nr->world->rep, nr->world->repkind);
+      maximize (param[i], world, nr, PROFILE, world->repkind);
       likes[i] = nr->llike;
       normd = nr->normd;
-      memcpy(param[i],world->param0,sizeof(double)*nr->partsize);
+      memcpy (param[i], world->param0, sizeof (double) * nr->partsize);
       trials = 1;
       if (method != 's')
-	prognose_profile_end (world->starttime, world->numpop2 + (long) world->options->gamma, nn);
+	prognose_profile_end (world->starttime,
+			      world->numpop2 + (long) world->options->gamma,
+			      nn);
     }
   if (method == 's')
     {
       spline = (spline_fmt *) calloc (1, sizeof (spline_fmt));
       setup_spline (spline);
-      prepare_spline_nodes (nn, which, param, likes, indeks, spline->param, spline->like);
+      prepare_spline_nodes (nn, which, param, likes, indeks, spline->param,
+			    spline->like);
       prepare_spline_first (spline->param, spline->like);
       prepare_spline_last (nn, spline->param, spline->like);
       calc_spline_diff (spline->diff, spline->param, spline->like, nn);
-      errc = calc_spline (spline->param, spline->like, nn, spline->constr, spline->diff, spline->diff2, spline->diagn, spline->work, spline->nwork);
+      errc =
+	calc_spline (spline->param, spline->like, nn, spline->constr,
+		     spline->diff, spline->diff2, spline->diagn, spline->work,
+		     spline->nwork);
       for (i = 0; i < nn - 1; i++)
 	{
 	  if (probabilities[i] < 0.5)
@@ -694,9 +769,13 @@ profile_max_spline (char method, long which, double *likes, double **param, worl
 	  x = (xhigh + xlow) / 2.;
 	  panic = 0;
 	  mid = testlike - 1000.;
-	  while (panic++ < MAX_PROFILE_TRIALS && fabs (mid - testlike) > BIGEPSILON)
+	  while (panic++ < MAX_PROFILE_TRIALS
+		 && fabs (mid - testlike) > BIGEPSILON)
 	    {
-	      mid = recalc_profilelike (x, spline->param, spline->like, nn, spline->diff, spline->diff2, spline->work, spline->nwork);
+	      mid =
+		recalc_profilelike (x, spline->param, spline->like, nn,
+				    spline->diff, spline->diff2, spline->work,
+				    spline->nwork);
 	      if (mid < low || mid > high)
 		break;
 	      if (testlike < mid)
@@ -714,18 +793,19 @@ profile_max_spline (char method, long which, double *likes, double **param, worl
 		  xlow = tmp;
 		}
 	    }
-	  xx = exp (x);
-	  nr->profilenum = set_profile_param (param[i], which, nr->profiles, 
-					      xx,
-					      nr->values, world);
-	  do_profiles(nr->world, nr, likes, &normd, PROFILE, 
-		      nr->world->rep, nr->world->repkind);
-	  //	  maximize(param[i], world, nr, PROFILE, world->repkind);
+	  xx = EXP (x);
+	  nr->profilenum = set_profile_param (param[i], which, nr->profiles,
+					      xx, nr->values, world);
+	  do_profiles (nr->world, nr, likes, &normd, PROFILE,
+		       nr->world->rep, nr->world->repkind);
+	  //      maximize(param[i], world, nr, PROFILE, world->repkind);
 	  likes[i] = nr->llike;
 	  normd = nr->normd;
-	  memcpy(param[i],world->param0,sizeof(double)*nr->partsize);
+	  memcpy (param[i], world->param0, sizeof (double) * nr->partsize);
 	  x = log (xx);
-	  prognose_profile_end (world->starttime, world->numpop2 + (long) world->options->gamma, nn);
+	  prognose_profile_end (world->starttime,
+				world->numpop2 + (long) world->options->gamma,
+				nn);
 	}
       destroy_spline (spline);
     }
@@ -775,7 +855,8 @@ destroy_spline (spline_fmt * spline)
    of  n+2 and not n
  */
 int
-calc_spline (double *param, double *like, long nn, long *constr, double *diff, double *diff2, long *diagn, double *work, long nwork)
+calc_spline (double *param, double *like, long nn, long *constr, double *diff,
+	     double *diff2, long *diagn, double *work, long nwork)
 {
   /* call to spline.c routines */
   long degree = 3;
@@ -786,13 +867,16 @@ calc_spline (double *param, double *like, long nn, long *constr, double *diff, d
   long kmax = 10;		//not used
   long maxstp = 10;		//not used
   long errc;
-  dbvssc_ (param, like, &nn, &degree, &smoothness, &opt, &d0, &dnp, &d20, &d2np, constr, &eps, NULL, NULL, NULL, NULL, &kmax, &maxstp, &errc, diff, diff2, diagn, work, &nwork);
+  dbvssc_ (param, like, &nn, &degree, &smoothness, &opt, &d0, &dnp, &d20,
+	   &d2np, constr, &eps, NULL, NULL, NULL, NULL, &kmax, &maxstp, &errc,
+	   diff, diff2, diagn, work, &nwork);
   /* end call to spline.c routines */
   return (long) errc;
 }
 
 void
-prepare_spline_nodes (long n, long which, double **rawparam, double *rawlikes, long *indeks, double *param, double *likes)
+prepare_spline_nodes (long n, long which, double **rawparam, double *rawlikes,
+		      long *indeks, double *param, double *likes)
 {
   long i;
   for (i = 0; i < n; i++)
@@ -809,7 +893,9 @@ prepare_spline_first (double *param, double *likes)
   const long i0 = 1;
   param[0] = log (SMALLEST_THETA);
 
-  likes[0] = ((likes[i] - likes[i0]) / (param[i] - param[i0]) * param[0]) + (likes[i0] + param[i0] * (likes[i] + likes[i0]) / (param[i] - param[i0]));
+  likes[0] =
+    ((likes[i] - likes[i0]) / (param[i] - param[i0]) * param[0]) +
+    (likes[i0] + param[i0] * (likes[i] + likes[i0]) / (param[i] - param[i0]));
 }
 
 void
@@ -818,7 +904,9 @@ prepare_spline_last (long n, double *param, double *likes)
   long n0 = n - 1;
   long n1 = n + 1;
   param[n1] = 100000. + param[n];
-  likes[n1] = ((likes[n] - likes[n0]) / (param[n] - param[n0]) * param[n1]) + (likes[n0] + param[n0] * (likes[n] + likes[n0]) / (param[n] - param[n0]));
+  likes[n1] =
+    ((likes[n] - likes[n0]) / (param[n] - param[n0]) * param[n1]) +
+    (likes[n0] + param[n0] * (likes[n] + likes[n0]) / (param[n] - param[n0]));
 }
 
 
@@ -830,7 +918,8 @@ calc_spline_diff (double *diff, double *param, double *likes, long n)
   diff[n] = ((likes[n] - likes[n + 1]) / (param[n] - param[n + 1]));
   for (i = 1; i < n; i++)
     {
-      diff[i] = ((likes[i + 1] - likes[i - 1]) / (param[i + 1] - param[i - 1]));
+      diff[i] =
+	((likes[i + 1] - likes[i - 1]) / (param[i + 1] - param[i - 1]));
     }
   diff[GRIDMIDDLE] = 0.0;
 }
@@ -841,7 +930,8 @@ calc_spline_diff (double *diff, double *param, double *likes, long n)
    testparam is THE LOG(testparam) !
  */
 double
-recalc_profilelike (double testparam, double *param, double *like, long nn, double *diff, double *diff2, double *work, long nwork)
+recalc_profilelike (double testparam, double *param, double *like, long nn,
+		    double *diff, double *diff2, double *work, long nwork)
 {
   long degree = 3;
   long smoothness = 1;
@@ -867,7 +957,8 @@ recalc_profilelike (double testparam, double *param, double *like, long nn, doub
 
   dbvsse_ (param, like, &nn, &degree, &smoothness,
 	   //gaga, &gagatab,
-	   &testparam, &ntab, &sbopt, &yy0, &yy1, &yy2, &errc, diff, diff2, y0tab, y1tab, y2tab, &erre, work, &nwork);
+	   &testparam, &ntab, &sbopt, &yy0, &yy1, &yy2, &errc, diff, diff2,
+	   y0tab, y1tab, y2tab, &erre, work, &nwork);
   //for(i=0;i<gagatab;i++)
   //printf("%f %f\n",gaga[i],y0tab[i]);
   //exit(0);
@@ -882,7 +973,7 @@ recalc_profilelike (double testparam, double *param, double *like, long nn, doub
 
 
 long
-set_profile_param (double *param, long which, long *allwhich, 
+set_profile_param (double *param, long which, long *allwhich,
 		   double xval, double *xvals, world_fmt * world)
 {
   boolean has_fixed = FALSE;
@@ -901,7 +992,10 @@ set_profile_param (double *param, long which, long *allwhich,
   if (strpbrk (world->options->custm, "0c"))
     {
       has_fixed = TRUE;
-      fixed = (long *) calloc (1, sizeof (long) * (numpop2 + (long) world->options->gamma));
+      fixed =
+	(long *) calloc (1,
+			 sizeof (long) * (numpop2 +
+					  (long) world->options->gamma));
       p = world->options->custm2;
       while (*p != '\0')
 	{
@@ -933,13 +1027,13 @@ set_profile_param (double *param, long which, long *allwhich,
       break;
     case 'S':
       z = 0;
-      while (z<world->options->sym2n && 
-	     which != world->options->sym2param[z][0] && 
+      while (z < world->options->sym2n &&
+	     which != world->options->sym2param[z][0] &&
 	     which != world->options->sym2param[z][1])
 	z++;
       param[world->options->sym2param[z][0]] = xval;
       param[world->options->sym2param[z][1]] = xval;
-      if(which==world->options->sym2param[z][0])
+      if (which == world->options->sym2param[z][0])
 	{
 	  allwhich[0] = which;
 	  allwhich[1] = world->options->sym2param[z][1];
@@ -960,13 +1054,13 @@ set_profile_param (double *param, long which, long *allwhich,
       break;
     case 's':
       z = 0;
-      while (z<world->options->symn && 
-	     which != world->options->symparam[z][0] && 
+      while (z < world->options->symn &&
+	     which != world->options->symparam[z][0] &&
 	     which != world->options->symparam[z][1])
 	z++;
       param[world->options->symparam[z][0]] = xval;
       param[world->options->symparam[z][1]] = xval;
-      if(which==world->options->symparam[z][0])
+      if (which == world->options->symparam[z][0])
 	{
 	  allwhich[0] = which;
 	  allwhich[1] = world->options->symparam[z][1];
@@ -1025,7 +1119,8 @@ set_profile_param (double *param, long which, long *allwhich,
 // len = length of the fixed array
 // PB 06/30/99
 void
-addinvar (double *param, long *fixed, long *allwhich, double *xvals, long start, long len)
+addinvar (double *param, long *fixed, long *allwhich, double *xvals,
+	  long start, long len)
 {
   long i, z = 0;
   for (i = start; i < len + start; i++)
@@ -1038,14 +1133,16 @@ addinvar (double *param, long *fixed, long *allwhich, double *xvals, long start,
 }
 
 long
-find_profilelike (double testlike, long whichprob, double minparam, double maxparam, 
-		  double *testparam, double *llike, long which, world_fmt * world, 
-		  boolean QD, boolean QD2, double *mlparam, double *normd, nr_fmt *nr)
+find_profilelike (double testlike, long whichprob, double minparam,
+		  double maxparam, double *testparam, double *llike,
+		  long which, world_fmt * world, boolean QD, boolean QD2,
+		  double *mlparam, double *normd, nr_fmt * nr)
 {
   const double probabilities[] = GRID;
-
-  //  boolean test;
+#ifndef MPI
   long locus, r;
+#endif
+  //  boolean test;
   double tmp;
   //  double likes=0;
   double xlow, low;
@@ -1054,7 +1151,7 @@ find_profilelike (double testlike, long whichprob, double minparam, double maxpa
   long panic = 0;
   helper_fmt helper;
   double *ltestparam;
-  ltestparam = (double *) calloc(nr->numpop2+1, sizeof(double));
+  ltestparam = (double *) calloc (nr->numpop2 + 1, sizeof (double));
   *normd = -1;
   if (probabilities[whichprob] < 0.5)
     {
@@ -1069,7 +1166,8 @@ find_profilelike (double testlike, long whichprob, double minparam, double maxpa
 	  if (maxparam < EPSILON)
 	    xlow = probabilities[whichprob] >= 0.98 ? 1000000.0 : minparam;
 	  else
-	    xlow = probabilities[whichprob] >= 0.98 ? maxparam * 10000 : minparam;
+	    xlow =
+	      probabilities[whichprob] >= 0.98 ? maxparam * 10000 : minparam;
 	}
       else
 	{
@@ -1098,35 +1196,34 @@ find_profilelike (double testlike, long whichprob, double minparam, double maxpa
 	    }
 	}
 #endif
-      memcpy (testparam, mlparam, sizeof (double) * 
+      memcpy (testparam, mlparam, sizeof (double) *
 	      (world->numpop2 + (long) world->options->gamma));
-      nr->profilenum = set_profile_param (testparam, which, nr->profiles, 
+      nr->profilenum = set_profile_param (testparam, which, nr->profiles,
 					  xlow, nr->values, world);
       testparam[which] = xlow;
-      set_logparam(ltestparam, testparam, nr->partsize);
-      fill_helper(&helper, testparam, ltestparam, nr->world, nr);
+      set_logparam (ltestparam, testparam, nr->partsize);
+      fill_helper (&helper, testparam, ltestparam, nr->world, nr);
       low = calc_loci_like (&helper, testparam, ltestparam);
-      memcpy (testparam, mlparam, sizeof (double) * 
+      memcpy (testparam, mlparam, sizeof (double) *
 	      (world->numpop2 + (long) world->options->gamma));
-      nr->profilenum = set_profile_param (testparam, which, nr->profiles, 
-					  xhigh,
-					  nr->values, world);
+      nr->profilenum = set_profile_param (testparam, which, nr->profiles,
+					  xhigh, nr->values, world);
       testparam[which] = xhigh;
-      set_logparam(ltestparam, testparam, nr->partsize);
+      set_logparam (ltestparam, testparam, nr->partsize);
       fill_helper (&helper, testparam, ltestparam, world, nr);
       high = calc_loci_like (&helper, testparam, ltestparam);
     }
   else
     {
-      memcpy(testparam, mlparam, sizeof(double)*nr->partsize);
-      nr->profilenum = set_profile_param (testparam, which, nr->profiles, 
+      memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+      nr->profilenum = set_profile_param (testparam, which, nr->profiles,
 					  xlow, nr->values, world);
-      maximize(testparam, world, nr, PROFILE, world->repkind);
+      maximize (testparam, world, nr, PROFILE, world->repkind);
       low = nr->llike;
-      memcpy(testparam, mlparam, sizeof(double)*nr->partsize);
-      nr->profilenum = set_profile_param (testparam, which, nr->profiles, 
+      memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+      nr->profilenum = set_profile_param (testparam, which, nr->profiles,
 					  xhigh, nr->values, world);
-      maximize(testparam, world, nr, PROFILE, world->repkind);
+      maximize (testparam, world, nr, PROFILE, world->repkind);
       high = nr->llike;
     }
   panic = 0;
@@ -1135,22 +1232,21 @@ find_profilelike (double testlike, long whichprob, double minparam, double maxpa
     {
       if (QD)
 	{
-	  memcpy(testparam, mlparam, sizeof(double)*nr->partsize);
-	  nr->profilenum = set_profile_param (testparam, which, 
-					      nr->profiles, x, 
+	  memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+	  nr->profilenum = set_profile_param (testparam, which,
+					      nr->profiles, x,
 					      nr->values, world);
 	  testparam[which] = x;
-	  set_logparam(ltestparam,testparam, nr->partsize);
+	  set_logparam (ltestparam, testparam, nr->partsize);
 	  fill_helper (&helper, testparam, ltestparam, world, nr);
 	  mid = calc_loci_like (&helper, testparam, ltestparam);
 	}
       else
 	{
-	  memcpy(testparam, mlparam, sizeof(double)*nr->partsize);
-	  nr->profilenum = set_profile_param (testparam, which, nr->profiles, 
-					      x, 
-					      nr->values, world);
-	  maximize(testparam, world, nr, PROFILE, world->repkind);
+	  memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+	  nr->profilenum = set_profile_param (testparam, which, nr->profiles,
+					      x, nr->values, world);
+	  maximize (testparam, world, nr, PROFILE, world->repkind);
 	  mid = *llike = nr->llike;
 	  *normd = nr->normd;
 	}
@@ -1178,23 +1274,26 @@ find_profilelike (double testlike, long whichprob, double minparam, double maxpa
       if (QD2)
 	{
 	  x = testparam[which];
-	  memcpy (testparam, mlparam, sizeof (double) * (nr->numpop2 + (long) world->options->gamma));
-	  nr->profilenum = set_profile_param (testparam, which, nr->profiles, 
-					      x, 
-					      nr->values, world);
-	  maximize(testparam, world, nr, PROFILE, world->repkind);
+	  memcpy (testparam, mlparam,
+		  sizeof (double) * (nr->numpop2 +
+				     (long) world->options->gamma));
+	  nr->profilenum =
+	    set_profile_param (testparam, which, nr->profiles, x, nr->values,
+			       world);
+	  maximize (testparam, world, nr, PROFILE, world->repkind);
 	  *llike = nr->llike;
 	  *normd = nr->normd;
-	  memcpy(testparam, world->param0, sizeof(double)*nr->partsize);
+	  memcpy (testparam, world->param0, sizeof (double) * nr->partsize);
 	}
     }
-  free(ltestparam);
+  free (ltestparam);
   return panic;
 }
 
 
 double
-interpolate (double xl, double xc, double xh, double low, double center, double high, double testlike)
+interpolate (double xl, double xc, double xh, double low, double center,
+	     double high, double testlike)
 {
   double xc2, xl2, xh2, a, b, c, x;
 
@@ -1202,11 +1301,18 @@ interpolate (double xl, double xc, double xh, double low, double center, double
   xl2 = xl * xl;
   xh2 = xh * xh;
 
-  a = (-(high * xc) + low * xc + center * xh - low * xh - center * xl + high * xl) / ((-xc + xh) * (xh - xl) * (-xc + xl));
+  a =
+    (-(high * xc) + low * xc + center * xh - low * xh - center * xl +
+     high * xl) / ((-xc + xh) * (xh - xl) * (-xc + xl));
 
-  b = (high * xc2 - low * xc2 - center * xh2 + low * xh2 + center * xl2 - high * xl2) / ((-xc + xh) * (xc - xl) * (-xh + xl));
+  b =
+    (high * xc2 - low * xc2 - center * xh2 + low * xh2 + center * xl2 -
+     high * xl2) / ((-xc + xh) * (xc - xl) * (-xh + xl));
 
-  c = -((low * xc2 * xh - low * xc * xh2 - high * xc2 * xl + center * xh2 * xl + high * xc * xl2 - center * xh * xl2) / ((-xc + xh) * (xc - xl) * (xh - xl)));
+  c =
+    -((low * xc2 * xh - low * xc * xh2 - high * xc2 * xl + center * xh2 * xl +
+       high * xc * xl2 - center * xh * xl2) / ((-xc + xh) * (xc - xl) * (xh -
+									 xl)));
 
 
   x = (-b - sqrt (b * b - 4 * a * (c - testlike))) / (2 * a);
@@ -1219,11 +1325,13 @@ void
 allocate_profile_percentiles (world_fmt * world)
 {
   long i;
-  world->quantiles = (quantile_fmt *) calloc (1, sizeof (quantile_fmt) * (world->numpop2 + 1));
+  world->quantiles =
+    (quantile_fmt *) calloc (1, sizeof (quantile_fmt) * (world->numpop2 + 1));
   for (i = 0; i < world->numpop2 + 1; i++)
     {
       world->quantiles[i].name = (char *) calloc (1, sizeof (char) * 20);
-      world->quantiles[i].param = (double *) calloc (1, sizeof (double) * GRIDSIZE);
+      world->quantiles[i].param =
+	(double *) calloc (1, sizeof (double) * GRIDSIZE);
     }
 }
 
@@ -1245,7 +1353,9 @@ print_menu_profile (long which, long nn)
 {
   char nowstr[LINESIZE];
   get_time (nowstr, "%H:%M:%S");
-  fprintf (stdout, "%s   Calculating profile likelihoods for parameter %2li out of %2li\n", nowstr, 1 + which, nn);
+  fprintf (stdout,
+	   "%s   Calculating profile likelihoods for parameter %2li out of %2li\n",
+	   nowstr, 1 + which, nn);
 }
 
 
