@@ -16,7 +16,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: random.c,v 1.24 2001/06/04 00:08:54 beerli Exp $
+$Id: random.c,v 1.25 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 
 #include "sighandler.h"
@@ -24,7 +24,7 @@ $Id: random.c,v 1.24 2001/06/04 00:08:54 beerli Exp $
 #include "heating.h"
 #include "random.h"
 #include "migrate_mpi.h"
-#ifdef SPRNG /*NCSA random number generator library, slower than ours*/
+#ifdef SPRNG			/*NCSA random number generator library, slower than ours */
 #define SIMPLE_SPRNG
 #ifdef MPI
 #ifndef USE_MPI
@@ -42,7 +42,7 @@ extern tpool_t heating_pool;
 
 /* prototypes ----------------------------------------- */
 void getseed (option_fmt * options);
-void swap_ptr(long ** ptr, long ** newptr);
+void swap_ptr (long **ptr, long **newptr);
 
 double randum (void);
 #ifdef PTHREADS
@@ -64,7 +64,7 @@ getseed (option_fmt * options)
   switch (options->autoseed)
     {
     case AUTO:
-      timeseed = abs((long) time (NULL));
+      timeseed = abs ((long) time (NULL));
       switch (timeseed % 4)
 	{
 	case 0:
@@ -80,7 +80,7 @@ getseed (option_fmt * options)
 	default:
 	  error ("Problem with automatic random number seed assignment");
 	}
-      options->inseed = abs((long) timeseed);
+      options->inseed = abs ((long) timeseed);
       break;
     case NOAUTO:
       break;
@@ -92,12 +92,12 @@ getseed (option_fmt * options)
     }
 #ifndef SPRNG
 #ifdef MPI
-  MPI_Bcast(&options->inseed, 1, MPI_LONG, MASTER, MPI_COMM_WORLD);
-  if(myID!=MASTER)
+  MPI_Bcast (&options->inseed, 1, MPI_LONG, MASTER, MPI_COMM_WORLD);
+  if (myID != MASTER)
     {
       for (i = 1; i <= 1000; i++)	/* clear the random number generator */
 	RANDUM ();
-      
+
       for (i = 0; i <= 2; i++)
 	seed[i] = 0;
       i = 0;
@@ -108,27 +108,35 @@ getseed (option_fmt * options)
 	  i++;
 	}
       while (options->inseed != 0);
-      
-      for(i=0; i < myID; i++)
+
+      for (i = 0; i < myID; i++)
 	{
-	  test = RANDINT(1,MAXLONG);
+	  test = RANDINT (1, MAXLONG);
 	  //printf("     %i %li> %li\n", myID, i, test); 
 	}
-      switch(test % 4)
+      switch (test % 4)
 	{
-	case 0: test++; break;
-	case 1: break;
-	case 2: test--; break;
-	case 3: test--; test--; break;
+	case 0:
+	  test++;
+	  break;
+	case 1:
+	  break;
+	case 2:
+	  test--;
+	  break;
+	case 3:
+	  test--;
+	  test--;
+	  break;
 	}
       options->inseed = test;
     }
-  printf("%i> random number seed = %li\n", myID, options->inseed); 
+  printf ("%i> random number seed = %li\n", myID, options->inseed);
 #endif
 #endif
   options->saveseed = options->inseed;
 #ifdef SPRNG
-  init_sprng(options->inseed, SPRNG_DEFAULT);
+  init_sprng (options->inseed, SPRNG_DEFAULT);
 #else /* if we do not have SPRNG */
   for (i = 1; i <= 1000; i++)	/* clear the random number generator */
     RANDUM ();
@@ -143,12 +151,13 @@ getseed (option_fmt * options)
       i++;
     }
   while (options->inseed != 0);
-#endif /* not SPRNG*/
+#endif /* not SPRNG */
 }
 
-void   swap_ptr(long ** ptr, long ** newptr)
+void
+swap_ptr (long **ptr, long **newptr)
 {
-  long * temp;
+  long *temp;
   temp = *ptr;
   *ptr = *newptr;
   *newptr = temp;
@@ -160,7 +169,7 @@ randum_thread (void)
 /* thread save random number generator */
 {
 #ifdef SPRNG
-  return sprng();
+  return sprng ();
 #else
   double value;
   //longer newseed;
@@ -177,14 +186,14 @@ randum_thread (void)
   newseed[2] += newseed[1] / 2048;
   newseed[1] &= 2047;
   newseed[2] += 1549 * seed[2] + 812 * seed[1];
-  swap_ptr(&newseed, &seed);
+  swap_ptr (&newseed, &seed);
   //  memcpy (seed, newseed, sizeof (longer));
   seed[2] &= 1023;
   value = (((seed[0] / 2048.0 + seed[1]) / 2048.0 + seed[2]) / 1024.0);
 #ifdef PTHREADS
   if ((pthread_mutex_unlock (&(heating_pool->random_lock))) != 0)
     error ("pthread_mutex_unlock failed in randum_thread()");
-#endif 
+#endif
   return value;
 #endif /*SPRNG*/
 }				/* randum */
@@ -194,7 +203,7 @@ randum (void)
 /* Non thread-safe random number generator (faster) */
 {
 #ifdef SPRNG
-  return sprng();
+  return sprng ();
 #else
   double value;
   //  longer newseed;
@@ -208,20 +217,10 @@ randum (void)
   newseed[1] &= 2047;
   newseed[2] += 1549 * seed[2] + 812 * seed[1];
   //memcpy (seed, newseed, sizeof (longer));
-  swap_ptr(&newseed, &seed);
+  swap_ptr (&newseed, &seed);
   seed[2] &= 1023;
   value = (((seed[0] / 2048.0 + seed[1]) / 2048.0 + seed[2]) / 1024.0);
   return value;
 #endif /*SPRNG*/
 }				/* randum */
 #endif
-
-
-
-
-
-
-
-
-
-
