@@ -31,15 +31,19 @@ extern void usererror (char string[], ...);
 extern void sig_error (char string[], char filename[], long line);
 #include <stdio.h>
 
-extern char * myfgets(char *buffer, long bufsize, FILE *infile);
+extern char *myfgets (char *buffer, long bufsize, FILE * infile);
 
 #ifdef NEXTAPP
 extern void malloc_error_found (int value);
 #endif
 #ifdef LAMARC_MALLOC
-extern void *LAMARC_malloc (const unsigned long size, const char file[], const long line);
-extern void *LAMARC_calloc (const unsigned long repeats, const unsigned long size, const char file[], const long line);
-extern void *LAMARC_realloc (void *ptr, const unsigned long size, const char file[], const long line);
+extern void *LAMARC_malloc (const unsigned long size, const char file[],
+			    const long line);
+extern void *LAMARC_calloc (const unsigned long repeats,
+			    const unsigned long size, const char file[],
+			    const long line);
+extern void *LAMARC_realloc (void *ptr, const unsigned long size,
+			     const char file[], const long line);
 #define malloc(a) LAMARC_malloc((unsigned long) a,__FILE__,__LINE__)
 #define calloc(b,a) LAMARC_calloc((unsigned long) b, a,__FILE__,__LINE__)
 #define realloc(c,a) LAMARC_realloc(c, (unsigned long) a,__FILE__,__LINE__)
