@@ -14,7 +14,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: tools.c,v 1.47 2001/07/02 21:30:30 beerli Exp $
+$Id: tools.c,v 1.48 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "data.h"
@@ -36,13 +36,15 @@ node *crawlback (const node * theNode);
 /*node *crawl(node * theNode); */
 node *showtop (node * theNode);
 void adjust_time (node * theNode, double tyme);
-void insert_migr_node (world_fmt * world, node * up, node * down, migr_table_fmt * migr_table, long *migr_table_counter);
+void insert_migr_node (world_fmt * world, node * up, node * down,
+		       migr_table_fmt * migr_table, long *migr_table_counter);
 void children (node * mother, node ** brother, node ** sister);
 /* math tools */
 double incompletegamma (double x, double alpha);
 double polygamma (long n, double z);
 void invert_matrix (double **a, long nsize);
-boolean nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2, boolean do_newton);
+boolean nrcheck (double **m, double **tm, double *v, long nrows, double *r1,
+		 double *r2, boolean do_newton);
 double rannor (double mean, double sd);
 char lowercase (char c);
 char uppercase (char c);
@@ -57,16 +59,17 @@ double mylgamma (double z);
 double logfac (long n);
 
 /* vector initialization */
-void doublevec1d(double **v, long size);
-void doublevec2d(double ***v, long size1, long size2);
-void free_doublevec2d(double **v);
-void setdoublevec1d(double **v, double *w, long size);
-void add_vector(double *result, double *v, long size);
+void doublevec1d (double **v, long size);
+void doublevec2d (double ***v, long size1, long size2);
+void free_doublevec2d (double **v);
+void setdoublevec1d (double **v, double *w, long size);
+void add_vector (double *result, double *v, long size);
 
 /*filemanipulation */
 void init_files (world_fmt * world, data_fmt * data, option_fmt * options);
 void exit_files (world_fmt * world, data_fmt * data, option_fmt * options);
-void openfile (FILE ** fp, char *filename, char *mode, const char *applic, char *perm);
+void openfile (FILE ** fp, char *filename, char *mode, const char *applic,
+	       char *perm);
 long read_savesum (world_fmt * world, option_fmt * options, data_fmt * data);
 void write_savesum (world_fmt * world);
 
@@ -102,47 +105,52 @@ void lu_decomp (double **m, long *indeks, long nrows);
 void lu_substitution (double **m, long *indeks, double *v, long nrows);
 double d1mach (long i);
 long i1mach (long i);
-int dpsifn (double *x, long *n, long kode, long m, double *ans, long *nz, long *ierr);
+int dpsifn (double *x, long *n, long kode, long m, double *ans, long *nz,
+	    long *ierr);
 double find_chi (long df, double prob);
 double probchi (long df, double chi);
 double chisquare (long df, double alpha);
 
-double
-chiboundary (long zeros, long nonzeros, double alpha);
+double chiboundary (long zeros, long nonzeros, double alpha);
 
 /* vector initialization */
-void doublevec1d(double **v, long size)
+void
+doublevec1d (double **v, long size)
 {
-  *v = (double *) calloc(size,sizeof(double));
+  *v = (double *) calloc (size, sizeof (double));
 }
 
-void doublevec2d(double ***v, long size1, long size2)
+void
+doublevec2d (double ***v, long size1, long size2)
 {
   long i;
-  *v = (double **) calloc(size1,sizeof(double *));
-  (*v)[0] = (double *) calloc(size1*size2,sizeof(double));
-  for(i=1;i<size1;i++)
+  *v = (double **) calloc (size1, sizeof (double *));
+  (*v)[0] = (double *) calloc (size1 * size2, sizeof (double));
+  for (i = 1; i < size1; i++)
     {
       (*v)[i] = (*v)[0] + size1 * i;
     }
 }
 
-void free_doublevec2d(double **v)
+void
+free_doublevec2d (double **v)
 {
-  free(v[0]);
-  free(v);
+  free (v[0]);
+  free (v);
 }
 
-void setdoublevec1d(double **v, double *w, long size)
+void
+setdoublevec1d (double **v, double *w, long size)
 {
-  doublevec1d(v, size);
-  memcpy(*v, w, sizeof(double) * size);
+  doublevec1d (v, size);
+  memcpy (*v, w, sizeof (double) * size);
 }
 
-void add_vector(double *result, double *v, long size)
+void
+add_vector (double *result, double *v, long size)
 {
   long i;
-  for(i=0; i<size; i++)
+  for (i = 0; i < size; i++)
     result[i] += v[i];
 }
 
@@ -191,23 +199,27 @@ void
 init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 {
   openfile (&data->infile, options->infilename, "r+", appl, NULL);
-  if(myID==MASTER)
+  if (myID == MASTER)
     {
       openfile (&world->outfile, options->outfilename, "w+", appl, NULL);
       if (options->treeprint > 0)
 	openfile (&world->treefile, options->treefilename, "w+", appl, NULL);
       if (options->mighist)
-	openfile (&world->mighistfile, options->mighistfilename, "w+", appl, NULL);
+	openfile (&world->mighistfile, options->mighistfilename, "w+", appl,
+		  NULL);
       if (options->writelog)
 	openfile (&options->logfile, options->logfilename, "w+", appl, NULL);
       if (options->writesum)
 	openfile (&data->sumfile, options->sumfilename, "w+", appl, NULL);
+      if (options->aic)
+	openfile (&options->aicfile, options->aicfilename, "w+", appl, NULL);
       if (options->plot)
 	{
 	  switch (options->plotmethod)
 	    {
 	    case 0:
-	      openfile (&world->mathfile, options->mathfilename, "w+", appl, NULL);
+	      openfile (&world->mathfile, options->mathfilename, "w+", appl,
+			NULL);
 	      break;
 	    default:		/*e.g. 0 this create just the plots in outfile */
 	      break;
@@ -222,7 +234,7 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
     openfile (&data->weightfile, options->weightfilename, "r+", appl, NULL);
   if (options->categs > 1)
     openfile (&data->catfile, options->catfilename, "r+", appl, NULL);
-   if (options->dist)
+  if (options->dist)
     openfile (&data->distfile, options->distfilename, "r+", appl, NULL);
   if (options->geo)
     openfile (&data->geofile, options->geofilename, "r+", appl, NULL);
@@ -251,6 +263,8 @@ exit_files (world_fmt * world, data_fmt * data, option_fmt * options)
     FClose (data->distfile);
   if (options->geo)
     FClose (data->geofile);
+  if (options->aic)
+    FClose (options->aicfile);
   if (options->plot && options->plotmethod == PLOTALL)
     FClose (world->mathfile);
   if (options->writesum || options->readsum)
@@ -360,16 +374,20 @@ print_llike (double llike, char *strllike)
 }
 
 void
-openfile (FILE ** fp, char *filename, char *mode, const char *application, char *perm)
+openfile (FILE ** fp, char *filename, char *mode, const char *application,
+	  char *perm)
 {
   int trials = 0;
   FILE *of = NULL;
-  char file[100];
+  char file[LINESIZE];
   char *p;
- 
-  if(( p = strpbrk(filename,CRLF))!=NULL)
-    *p =  '\0';
-  strncpy (file, filename,99);
+
+  if ((p = strpbrk (filename, CRLF)) != NULL)
+    *p = '\0';
+  strncpy (file, filename, LINESIZE - 1);
+// not needed anymore?
+  //file[strlen (file) - 1] = '\0';
+
   while (trials++ < 10)
     {
       of = fopen (file, mode);
@@ -399,7 +417,6 @@ openfile (FILE ** fp, char *filename, char *mode, const char *application, char
 	      break;
 	    }
 	}
-      file[strlen (file) - 1] = '\0';
     }
   if (trials >= 10)
     {
@@ -416,7 +433,7 @@ openfile (FILE ** fp, char *filename, char *mode, const char *application, char
 long
 read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 {
-  long Gmax=0;
+  long Gmax = 0;
   FILE *sumfile = data->sumfile;
   timearchive_fmt **ta;
   long nrep = 0;
@@ -439,11 +456,15 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 	}
       else
 	newstyle = FALSE;
-      hits = sscanf (input, "%li %li %li %li %li", &world->loci, &world->numpop, &world->numpop2, &tmp, &options->replicatenum);
+      hits =
+	sscanf (input, "%li %li %li %li %li", &world->loci, &world->numpop,
+		&world->numpop2, &tmp, &options->replicatenum);
       if (hits != 5)
 	{
 	  nrep = 1;
-	  hits = sscanf (input, "%li %li %li", &world->loci, &world->numpop, &world->numpop2);
+	  hits =
+	    sscanf (input, "%li %li %li", &world->loci, &world->numpop,
+		    &world->numpop2);
 	  options->replicate = FALSE;
 	  options->replicatenum = 0;
 	}
@@ -455,7 +476,9 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 	  options->replicate = (boolean) tmp;
 	}
       data->loci = world->loci;
-      data->skiploci = (boolean *) realloc (data->skiploci, sizeof (boolean) * (data->loci + 1));
+      data->skiploci =
+	(boolean *) realloc (data->skiploci,
+			     sizeof (boolean) * (data->loci + 1));
       memset (data->skiploci, 0, sizeof (boolean) * (data->loci + 1));
       read_geofile (data, options, world->numpop);
       data->numpop = world->numpop;
@@ -466,17 +489,20 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 	for (r = 0; r < nrep; r++)
 	  {
 	    FGETS (input, 1024, sumfile);
-	    fscanf (sumfile, "%li %li %li\n", &ta[r][l].T, &ta[r][l].numpop, &ta[r][l].sumtips);
+	    fscanf (sumfile, "%li %li %li\n", &ta[r][l].T, &ta[r][l].numpop,
+		    &ta[r][l].sumtips);
 	    Gmax = (ta[r][l].T > Gmax) ? ta[r][l].T : Gmax;
 	    ta[r][l].allocT = 0;
 	    increase_timearchive (world, l, ta[r][l].T, world->numpop, r);
-	    fscanf (sumfile, "%lg %lg %lg\n", &ta[r][l].param_like, &ta[r][l].thb, &ta[r][l].alpha);
+	    fscanf (sumfile, "%lg %lg %lg\n", &ta[r][l].param_like,
+		    &ta[r][l].thb, &ta[r][l].alpha);
 	    for (i = 0; i < world->atl[r][l].T; i++)
 	      {
 		fscanf (sumfile, "%li ", &ta[r][l].tl[i].copies);
 		for (j = 0; j < world->numpop; j++)
 		  {
-		    fscanf (sumfile, "%lf %lf %lf\n", &ta[r][l].tl[i].km[j], &ta[r][l].tl[i].kt[j], &ta[r][l].tl[i].p[j]);
+		    fscanf (sumfile, "%lf %lf %lf\n", &ta[r][l].tl[i].km[j],
+			    &ta[r][l].tl[i].kt[j], &ta[r][l].tl[i].p[j]);
 		  }
 		if (newstyle)
 		  {
@@ -504,7 +530,8 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 	      }
 	    for (i = 0; i < world->numpop2; i++)
 	      {
-		fscanf (sumfile, "%lg %lg\n", &ta[r][l].param[i], &ta[r][l].param0[i]);
+		fscanf (sumfile, "%lg %lg\n", &ta[r][l].param[i],
+			&ta[r][l].param0[i]);
 	      }
 	    log_param0 (ta[r][l].param0, ta[r][l].lparam0, world->numpop2);
 	    //for(i=0;i<ta[l].T;i++)
@@ -539,20 +566,28 @@ write_savesum (world_fmt * world)
     }
   else
     repmax = 1;
-  fprintf (sumfile, "# begin genealogy-summary file of migrate %s ------\n#\n", MIGRATEVERSION);
-  fprintf (sumfile, "%li %li %li %li %li\n", world->loci, world->numpop, world->numpop2, (long) world->options->replicate, repmax);
+  fprintf (sumfile,
+	   "# begin genealogy-summary file of migrate %s ------\n#\n",
+	   MIGRATEVERSION);
+  fprintf (sumfile, "%li %li %li %li %li\n", world->loci, world->numpop,
+	   world->numpop2, (long) world->options->replicate, repmax);
   for (l = 0; l < world->loci; l++)
     {
       for (r = 0; r < repmax; r++)
 	{
-	  fprintf (sumfile, "%li %li ####### locus %li, replicate %li ################\n%li %li %li\n", l, r, l, r, ta[r][l].T, ta[r][l].numpop, ta[r][l].sumtips);
-	  fprintf (sumfile, "%20.20g %20.20g %20.20g\n", ta[r][l].param_like, ta[r][l].thb, ta[r][l].alpha);
+	  fprintf (sumfile,
+		   "%li %li ####### locus %li, replicate %li ################\n%li %li %li\n",
+		   l, r, l, r, ta[r][l].T, ta[r][l].numpop, ta[r][l].sumtips);
+	  fprintf (sumfile, "%20.20g %20.20g %20.20g\n", ta[r][l].param_like,
+		   ta[r][l].thb, ta[r][l].alpha);
 	  for (i = 0; i < ta[r][l].T; i++)
 	    {
 	      fprintf (sumfile, "%li ", ta[r][l].tl[i].copies);
 	      for (j = 0; j < world->numpop; j++)
 		{
-		  fprintf (sumfile, "%20.20f %20.20f %f\n", ta[r][l].tl[i].km[j], ta[r][l].tl[i].kt[j], ta[r][l].tl[i].p[j]);
+		  fprintf (sumfile, "%20.20f %20.20f %f\n",
+			   ta[r][l].tl[i].km[j], ta[r][l].tl[i].kt[j],
+			   ta[r][l].tl[i].p[j]);
 		}
 	      for (j = 0; j < world->numpop2; j++)
 		{
@@ -563,7 +598,8 @@ write_savesum (world_fmt * world)
 	    }
 	  for (i = 0; i < world->numpop2; i++)
 	    {
-	      fprintf (sumfile, "%20.20e %20.20e\n", ta[r][l].param[i], ta[r][l].param0[i]);
+	      fprintf (sumfile, "%20.20e %20.20e\n", ta[r][l].param[i],
+		       ta[r][l].param0[i]);
 	    }
 	  //  for(i=0;i<ta[l].T;i++)
 	  //        {
@@ -573,7 +609,8 @@ write_savesum (world_fmt * world)
 	  fprintf (sumfile, "%li %20.20e\n", ta[r][l].trials, ta[r][l].normd);
 	}
     }
-  fprintf (sumfile, "# end genealogy-summary file of migrate %s ------\n", MIGRATEVERSION);
+  fprintf (sumfile, "# end genealogy-summary file of migrate %s ------\n",
+	   MIGRATEVERSION);
   fflush (sumfile);
 }
 
@@ -683,7 +720,8 @@ adjust_time (node * theNode, double tyme)
 }
 
 void
-insert_migr_node (world_fmt * world, node * up, node * down, migr_table_fmt * migr_table, long *migr_table_counter)
+insert_migr_node (world_fmt * world, node * up, node * down,
+		  migr_table_fmt * migr_table, long *migr_table_counter)
 {
   long i, panic;
   node *tmp, *tmp2, *oldNode, *oldNode2, *theNode;
@@ -691,13 +729,15 @@ insert_migr_node (world_fmt * world, node * up, node * down, migr_table_fmt * mi
     error ("up has to be a top-node");
   theNode = showtop (up)->back;
   if (*migr_table_counter > 0 && up->tyme > migr_table[0].time)
-    error ("insert_migr_node: the first migration node has a wrong time for up");
+    error
+      ("insert_migr_node: the first migration node has a wrong time for up");
   if (migr_table[(*migr_table_counter) - 1].from != down->actualpop)
     {
       error ("this should never happen -> wrong choice of nodes\n");
       (*migr_table_counter)--;
     }
-  if (((*migr_table_counter) > 0) && (migr_table[(*migr_table_counter) - 1].from != down->actualpop))
+  if (((*migr_table_counter) > 0)
+      && (migr_table[(*migr_table_counter) - 1].from != down->actualpop))
     error ("problem catched in inser_migr_table");
   for (i = 0; i < (*migr_table_counter); i++)
     {
@@ -826,13 +866,15 @@ incompletegamma (double x, double alpha)
   /*  Check that we have valid values for X and P */
   if (alpha <= 0. || x < 0.)
     error ("failed in imcompletegamma(): wrong alpha or x\n");
-  if (fabs(x) < DBL_EPSILON)
+  if (fabs (x) < DBL_EPSILON)
     return gama;
 
   /*  Use a normal approximation if P > PLIMIT */
   if (alpha > 1e3)
     {
-      pn1 = sqrt (alpha) * 3. * (pow (x / alpha, (1. / 3.)) + 1. / (alpha * 9.) - 1.);
+      pn1 =
+	sqrt (alpha) * 3. * (pow (x / alpha, (1. / 3.)) + 1. / (alpha * 9.) -
+			     1.);
       gama = alnorm (pn1, FALSE);
       return gama;
     }
@@ -862,7 +904,7 @@ incompletegamma (double x, double alpha)
       gama = 0.;
       if (arg >= -88.)
 	{
-	  gama = exp (arg);
+	  gama = EXP (arg);
 	}
 
     }
@@ -897,7 +939,7 @@ incompletegamma (double x, double alpha)
 		  gama = 1.;
 		  if (arg >= -88.)
 		    {
-		      gama = 1. - exp (arg);
+		      gama = 1. - EXP (arg);
 		    }
 		  return gama;
 		}
@@ -942,7 +984,8 @@ polygamma (long n, double z)
 /* syntax: nrcheck(matrix,inversematrix,ncols=nrows,returnval1,returnval2) */
 /* mai 95 PB                                             */
 boolean
-nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2, boolean do_newton)
+nrcheck (double **m, double **tm, double *v, long nrows, double *r1,
+	 double *r2, boolean do_newton)
 {
   long i, j, k;
   double *tmp, *tmp2, tmp3 = 0.0, tmp4 = 0.0;
@@ -971,7 +1014,7 @@ nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2,
     }
   tmp4 = log (fabs ((*r1)));
   tmp4 = tmp4 + tmp4 - log (fabs ((*r2)));
-  tmp4 = ((*r2) < 0 ? -1 : 1) * exp (tmp4);
+  tmp4 = ((*r2) < 0 ? -1 : 1) * EXP (tmp4);
   free (tmp);
   if (do_newton && (tmp3 > (tmp4 > 0 ? tmp4 : 0)))
     {
@@ -1180,10 +1223,17 @@ alnorm (double x, int up)
       y = half * x * x;
       if (x > con)
 	{
-	  result = r * exp (-y) / (x + c1 + d1 / (x + c2 + d2 / (x + c3 + d3 / (x + c4 + d4 / (x + c5 + d5 / (x + c6))))));
+	  result =
+	    r * EXP (-y) / (x + c1 +
+			    d1 / (x + c2 +
+				  d2 / (x + c3 +
+					d3 / (x + c4 +
+					      d4 / (x + c5 +
+						    d5 / (x + c6))))));
 	  return ((!up) ? one - result : result);
 	}
-      result = half - x * (p - q * y / (y + a1 + b1 / (y + a2 + b2 / (y + a3))));
+      result =
+	half - x * (p - q * y / (y + a1 + b1 / (y + a2 + b2 / (y + a3))));
       return ((!up) ? one - result : result);
     }
   else
@@ -1376,7 +1426,8 @@ i1mach (long i)
 }
 
 int
-dpsifn (double *x, long *n, long kode, long m, double *ans, long *nz, long *ierr)
+dpsifn (double *x, long *n, long kode, long m, double *ans, long *nz,
+	long *ierr)
 {
   /* Initialized data */
 
@@ -1406,7 +1457,8 @@ dpsifn (double *x, long *n, long kode, long m, double *ans, long *nz, long *ierr
   /*static */ long mm, nn, np;
   /*static */ double fx, tk;
   /*static */ long mx, nx;
-  /*static */ double xm, tt, xq, den, arg, fln, r1m4, r1m5, eps, rln, tol, xln, trm[22], tss, tst;
+  /*static */ double xm, tt, xq, den, arg, fln, r1m4, r1m5, eps, rln, tol,
+    xln, trm[22], tss, tst;
 
   /* Parameter adjustments */
   --ans;
@@ -1484,7 +1536,7 @@ L41:
   xm = rln * -2.302 - MIN (0., xln);
   arg = xm / *n;
   arg = MIN (0., arg);
-  eps = exp (arg);
+  eps = EXP (arg);
   xm = 1. - eps;
   if (fabs (arg) < .001)
     {
@@ -1522,7 +1574,7 @@ L60:
     {
       goto L380;
     }
-  tss = exp (-t);
+  tss = EXP (-t);
   tt = .5 / xdmy;
   t1 = tt;
   tst = wdtol * tt;
@@ -1689,7 +1741,7 @@ L200:
   nn = (long) fln + 1;
   np = *n + 1;
   t1 = (*n + 1) * xln;
-  t = exp (-t1);
+  t = EXP (-t1);
   s = t;
   den = *x;
   i1 = nn;
@@ -1857,7 +1909,7 @@ probchi (long df, double chi)
   double v = ((double) df) / 2.;
   if (chi > DBL_EPSILON && v > DBL_EPSILON)
     {
-      //lg = exp (LGAMMA (v));
+      //lg = EXP (LGAMMA (v));
       prob = 1. - incompletegamma (chi / 2., v);
     }
   else
@@ -1868,21 +1920,23 @@ probchi (long df, double chi)
   return prob;
 }
 
-double probchiboundary(double chi, long zeros, long all)
+double
+probchiboundary (double chi, long zeros, long all)
 {
   double a, b, m;
-  double xb = 1.0;//1.0-EPSILON/1000.;
-  double xa = 0.0;//EPSILON/1000.;
+  double xb = 1.0;		//1.0-EPSILON/1000.;
+  double xa = 0.0;		//EPSILON/1000.;
   double xm = 0.51;
   double nonzeros = all - zeros;
-  if(zeros==0)
+  if (zeros == 0)
     {
-      return probchi(all,chi);
+      return probchi (all, chi);
     }
   a = chiboundary (zeros, nonzeros, xa);
   m = chiboundary (zeros, nonzeros, xm);
   b = chiboundary (zeros, nonzeros, xb);
-  while (fabs (m - chi) > EPSILON && (fabs(xa-xm)>EPSILON && fabs(xb-xm)>EPSILON))
+  while (fabs (m - chi) > EPSILON
+	 && (fabs (xa - xm) > EPSILON && fabs (xb - xm) > EPSILON))
     {
       if (m < chi)
 	{
@@ -1894,7 +1948,8 @@ double probchiboundary(double chi, long zeros, long all)
 	  a = m;
 	  xa = xm;
 	}
-      xm = /*(-(b * xa) + chi * xa + a * xb - chi * xb) / (a - b);	*/(xa + xb)/2.;
+      xm =			/*(-(b * xa) + chi * xa + a * xb - chi * xb) / (a - b);      */
+	(xa + xb) / 2.;
 
       m = chiboundary (zeros, nonzeros, xm);
     }
@@ -1905,17 +1960,17 @@ double
 chiboundary (long zeros, long nonzeros, double alpha)
 {
   //  double prob;
-  double sum=0.;
+  double sum = 0.;
   long i;
-  long k=zeros;
+  long k = zeros;
   double freq;
   double summ;
   //printf("z=%li a=%4.2f ", k,alpha);
-  for(i=0;i<=zeros;i++)
+  for (i = 0; i <= zeros; i++)
     {
-      //      sum = zerovec[i] 	* (i+nonzeros) == 0 ? 0. : find_chi(i+nonzeros,alpha);
-      freq = exp(logfac(k)-logfac(k-i)-logfac(i)-LOG2*k);
-      summ = (i+nonzeros) == 0 ? 0. : find_chi(i+nonzeros,alpha);
+      //      sum = zerovec[i]  * (i+nonzeros) == 0 ? 0. : find_chi(i+nonzeros,alpha);
+      freq = EXP (logfac (k) - logfac (k - i) - logfac (i) - LOG2 * k);
+      summ = (i + nonzeros) == 0 ? 0. : find_chi (i + nonzeros, alpha);
       //      printf(" %.2f(%.4f)",freq*pow(2.,k),summ);
       sum += freq * summ;
     }
@@ -1927,8 +1982,10 @@ chiboundary (long zeros, long nonzeros, double alpha)
 double
 chisquare (long df, double alpha)
 {
-  const double table05[] = { 3.84146, 5.99147, 7.81473, 9.48773, 11.0705, 12.5916 };
-  const double table01[] = { 6.63490, 9.21034, 11.3449, 13.2767, 15.0863, 16.8119 };
+  const double table05[] =
+    { 3.84146, 5.99147, 7.81473, 9.48773, 11.0705, 12.5916 };
+  const double table01[] =
+    { 6.63490, 9.21034, 11.3449, 13.2767, 15.0863, 16.8119 };
 
   if (alpha == 0.05)
     return table05[df - 1];
@@ -1951,7 +2008,8 @@ sum (double *vector, long n)
 //==========================================
 // searching and finding
 
-boolean find (long i, long *list, long listlen)
+boolean
+find (long i, long *list, long listlen)
 {
   long j;
   for (j = 0; j < listlen; j++)
@@ -2085,10 +2143,10 @@ gamma_rates (double *rate, double *probcat, long categs, char *input)
     input++;
   if ((value = strtod (input, (char **) NULL)) > 0)
     alpha = value;
-  initgammacat(categs,alpha,1.,rate,probcat);
+  initgammacat (categs, alpha, 1., rate, probcat);
   for (i = 0; i < categs; i++)
     {
-      probcat[i] = exp(probcat[i]);
+      probcat[i] = EXP (probcat[i]);
     }
   //  calc_gamma (alpha, rate, categs);
 }
@@ -2099,7 +2157,8 @@ void
 calc_gamma (double alpha, double *gama, long categs)
 {
   long i, panic;
-  double low, mid, high, xlow, xhigh, tmp, freq = 0, x = 10, elements = (double) categs;
+  double low, mid, high, xlow, xhigh, tmp, freq = 0, x = 10, elements =
+    (double) categs;
   freq = -(0.5 / elements);	/*so we have midpoints instead of endpoints */
   for (i = 0; i < categs; i++)
     {
@@ -2180,7 +2239,8 @@ print_line (FILE * outfile, char c, long nn, long flag)
   fputc ('\n', outfile);
 }
 
-char sgetc(char **buffer)
+char
+sgetc (char **buffer)
 {
   char ch;
   ch = **buffer;
@@ -2189,18 +2249,19 @@ char sgetc(char **buffer)
 }
 
 
-char *sgets(char *s, int size, char **stream)
+char *
+sgets (char *s, int size, char **stream)
 {
-  long ch='\0';
+  long ch = '\0';
   long counter = 0;
-  while(counter < size-1)
+  while (counter < size - 1)
     {
       ch = **stream;
       (*stream)++;
-      switch(ch)
+      switch (ch)
 	{
 	case '\n':
-	  s[counter]='\0';
+	  s[counter] = '\0';
 	  return s;
 	default:
 	  s[counter] = ch;
@@ -2210,6 +2271,3 @@ char *sgets(char *s, int size, char **stream)
     }
   return s;
 }
-
-
-
